<TeXmacs|1.0.5.12>

<project|ln.tp>

<style|tmbook>

<\body>
  <assign|chapter-nr|2><with|mode|math|<assign|tf|<wide|f|~>><assign|tP|<wide|P|~>><assign|tmu|<wide|\<mu\>|~>><assign|tnu|<wide|\<nu\>|~>><assign|mz|\<frak-z\>><assign|MZ|\<frak-Z\>>><chapter|The
  Newton polygon method>

  <glossary-line|<vspace*|1fn><strong|Chapter 3. The Newton polygon
  method><vspace|1fn>><label|npol-chap>Almost all techniques for solving
  asymptotic systems of equations are explicitly or implicitly based on the
  Newton polygon method. In this section we explain this technique in the
  elementary case of algebraic equations over grid-based algebras
  <no-break><with|mode|math|C<gb|\<frak-M\>>>, where <with|mode|math|C> is a
  constant field of characteristic zero and <with|mode|math|\<frak-M\>> a
  totally ordered monomial group with <with|mode|math|\<bbb-Q\>>-powers. In
  later chapters of this book, the method will be generalized to linear and
  non-linear differential equations.

  In section <reference|Npol-ex-sec>, we first illustrate the Newton polygon
  method by some examples. One important feature of our exposition is that we
  systematically work with ``asymptotic algebraic equations'', which are
  polynomial equations <with|mode|math|P(f)=0> over
  <with|mode|math|C<gb|\<frak-M\>>> together with asymptotic side-conditions,
  like <with|mode|math|f\<prec\>\<frak-v\>>. Asymptotic algebraic equations
  admit natural invariants, like the ``Newton degree'', which are useful in
  the termination proof of the method. Another important ingredient is the
  consideration of equations <with|mode|math|P<rprime|'>(f)=0>,
  <with|mode|math|P<rprime|''>(f)=0>, <abbr|etc.> in the case when
  <with|mode|math|P(f)=0> almost admits almost multiple roots.

  In section <reference|impl-ser-sec>, we prove a version of the implicit
  function theorem for grid-based series. Our proof uses a syntactic
  technique which will be further generalized in chapter
  <no-break><reference|gbop>. The implicit function theorem corresponds to
  the resolution of asymptotic algebraic equations of Newton degree one. In
  section <reference|N:Newton:alg>, we show how to compute the solutions to
  an asymptotic algebraic equation using the Newton polygon method. We also
  prove that <with|mode|math|C<gb|\<frak-M\>>> is algebraically closed or
  real closed, if this is the case for <with|mode|math|C>.

  The end of this chapter contains a digression on ``Cartesian
  representations'', which allow for a finer finer calculus on grid-based
  series. This calculus is based on the observation that any grid-based
  series can be represented by a multivariate Laurent series. By restricting
  these Laurent series to be of a special form, it is possible to define
  special types of grid-based series, such as convergent, algebraic or
  effective grid-based series. In section <reference|LC>, we will show that
  the Newton polygon method can again be applied to these more special types
  of grid-based series.

  Cartesian representations are essential for the development of effective
  asymptotics <cite|vdH:phd>, but they will only rarely occur in the sequel
  of this book (the main exceptions being section <reference|cv-tr-sec> and
  some of the exercises). Therefore, sections <no-break><reference|CR-sec>
  and <no-break><reference|LC> may be skipped at a first reading.

  \;

  <section|The method illustrated by examples><label|Npol-ex-sec>

  <subsection|The Newton polygon and its slopes>

  Consider the equation

  <equation|<label|N:New:ex1>P(f)=<big|sum><rsub|i\<geqslant\>0>P<rsub|i>*f<rsup|i>=z<rsup|3>*f<rsup|6>+z<rsup|4>*f<rsup|5>+f<rsup|4>-2*f<rsup|3>+f<rsup|2>+<frac|z|1-z<rsup|2>>*f+<frac|z<rsup|3>|1-z>=0>

  and a Puiseux series <with|mode|math|f=c*z<rsup|\<mu\>>+\<cdots\>\<in\>\<bbb-C\>[c]<gb|z<rsup|\<bbb-Q\>>>>,
  where <with|mode|math|c\<neq\>0> is a formal parameter. We call
  <with|mode|math|\<mu\>=val f> the <em|dominant
  exponent><subindex|dominant|exponent><subindex|series|dominant exponent> or
  <em|valuation><index|valuation><subindex|series|valuation> of
  <with|mode|math|f>. Then

  <equation*|\<alpha\>=min<rsub|i> val(P<rsub|i>*z<rsup|i*\<mu\>>)= min
  {3,\<mu\>+1,2*\<mu\>,3*\<mu\>,4*\<mu\>,5*\<mu\>+4,6*\<mu\>+3}>

  is the dominant exponent of <with|mode|math|P(f)\<in\>\<bbb-C\>[c]<gb|z<rsup|\<bbb-Q\>>>>
  and

  <equation|<label|N:New:ex1b>N<rsub|P,z<rsup|\<mu\>>>(c)\<assign\>P(f)<rsub|z<rsup|\<alpha\>>>=0>

  is a non-trivial polynomial equation in <with|mode|math|c>. We call
  <with|mode|math|N<rsub|P,z<rsup|\<mu\>>>> and (<reference|N:New:ex1b>) the
  <em|Newton polynomial><bi-index|Newton|polynomial> <abbr|resp.> <em|Newton
  equation><bi-index|Newton|equation> associated to
  <with|mode|math|z<rsup|\<mu\>>>.

  Let us now replace <with|mode|math|c> by a non-zero value in
  <with|mode|math|C>, so that <with|mode|math|f=c*z<rsup|\<mu\>>+\<cdots\>\<in\>\<bbb-C\><gb|z<rsup|\<bbb-Q\>>>>.
  If <with|mode|math|f> is a solution to (<reference|N:New:ex1>), then we
  have in particular <with|mode|math|N<rsub|P,z<rsup|\<mu\>>>(c)=0>.
  Consequently, <with|mode|math|N<rsub|P,z<rsup|\<mu\>>>> must contain at
  least two terms, so that <with|mode|math|\<alpha\>> occurs at least twice
  among the numbers <with|mode|math|3,\<mu\>+1,2*\<mu\>,3*\<mu\>,4*\<mu\>,5*\<mu\>+4,6*\<mu\>+3>.
  It follows that

  <equation*|\<mu\>\<in\>{2,1,0,\<um\><with|math-display|false|<frac|3|2>>}.>

  We call <with|mode|math|2,1,0> and <with|mode|math|\<um\><frac|3|2>> the
  <em|starting exponents><subindex|starting|exponent> for
  (<reference|N:New:ex1>). The corresponding monomials
  <with|mode|math|z<rsup|2>>, <with|mode|math|z>, <with|mode|math|1> and
  <with|mode|math|z<rsup|\<um\>3/2>> are called <em|starting
  monomials><subindex|starting|monomial> for (<reference|N:New:ex1>).

  The starting exponents may be determined graphically from the <em|Newton
  polygon><subindex|Newton|polygon> associated to (<reference|N:New:ex1>),
  which is defined to be the convex hull of all points
  <with|mode|math|(i,\<nu\>)> with <with|mode|math|\<nu\>\<geqslant\>val
  P<rsub|i>>. Here points <with|mode|math|(i,\<nu\>)\<in\>\<bbb-N\>\<times\>\<bbb-Q\>>
  really encode points <with|mode|math|(f<rsup|i>,z<rsup|\<nu\>>)\<in\>f<rsup|\<bbb-N\>>\<times\>z<rsup|\<bbb-Q\>>>
  (recall the explanations below figure <reference|gb-fig>). The Newton
  polygon associated to<nbsp>(<reference|N:New:ex1>) is drawn at the left
  hand side of figure <no-break><reference|Newpolfig>. The diagonal slopes

  <eqnarray*|<tformat|<table|<row|<cell|(1,z<rsup|3>)>|<cell|\<rightarrow\>>|<cell|(f,z)<htab|5mm>(\<mu\>=2)>>|<row|<cell|(f,z)>|<cell|\<rightarrow\>>|<cell|(f<rsup|2>,1)<htab|5mm>(\<mu\>=1)>>|<row|<cell|(f<rsup|2>,1)>|<cell|\<rightarrow\>>|<cell|(f<rsup|4>,1)<htab|5mm>(\<mu\>=0)>>|<row|<cell|(f<rsup|4>,1)>|<cell|\<rightarrow\>>|<cell|(f<rsup|6>,z<rsup|3>)<htab|5mm>(\<mu\>=\<um\><with|math-display|false|<frac|3|2>>)>>>>>

  correspond to the starting exponents for (<reference|N:New:ex1>).

  Given a starting exponent <with|mode|math|\<mu\> \<in\> \<bbb-Q\>> for
  (<reference|N:New:ex1>), a non-zero solution <with|mode|math|c> of the
  corresponding Newton equation is called a <em|starting
  coefficient><subindex|starting|coefficient> and
  <with|mode|math|c*z<rsup|\<mu\>>> a <em|starting
  term><subindex|starting|term>. Below, we listed the starting coefficients
  <with|mode|math|c> as a function of <with|mode|math|\<mu\>> in the case of
  equation<nbsp>(<reference|N:New:ex1b>):

  <\equation*>
    <block*|<tformat|<cwith|1|1|1|4|cell-background|pastel
    blue>|<table|<row|<cell|\<mu\>>|<cell|N<rsub|P,\<mu\>>>|<cell|c>|<cell|<with|mode|text|multiplicity>>>|<row|<cell|2>|<cell|c+1>|<cell|\<um\>1>|<cell|1>>|<row|<cell|1>|<cell|c<rsup|2>+c>|<cell|\<um\>1>|<cell|1>>|<row|<cell|0>|<cell|c<rsup|4>-2*c<rsup|3>+c<rsup|2>>|<cell|1>|<cell|2>>|<row|<cell|<with|math-display|false|<frac|3|2>>>|<cell|c<rsup|6>+c<rsup|4>>|<cell|\<um\>\<mathi\>,\<mathi\>>|<cell|1>>>>>
  </equation*>

  <\big-figure|<postscript|figures/Npol1.ps|*3/5|*3/5||||><space|4spc><postscript|figures/Npol2.ps|*3/5|*3/5||||>>
    <label|Newpolfig>The left-hand side shows the Newton polygon associated
    to the equation (<reference|N:New:ex1>). The slopes of the four edges
    correspond to the starting exponents <with|mode|math|2>,
    <with|mode|math|1>, <with|mode|math|0> and
    <with|mode|math|\<um\><frac|3|2>> (from left to right). After the
    substitution <with|mode|math|f\<rightarrow\>1+<tf><space|1.2spc>(<wide|f|~>\<prec\>1)>,
    we obtain the equation (<reference|N:New:ex1c>), whose Newton polygon is
    shown at the right-hand side. Each non-zero coefficient
    <with|mode|math|P<rsub|i,z<rsup|\<alpha\>>>> in the equation
    (<reference|N:New:ex1>) for <with|mode|math|f> induces a ``row'' of
    (potentially) non-zero coefficients <with|mode|math|<wide|P|~><rsub|<wide|\<imath\>|~>,z<rsup|<wide|\<alpha\>|~>>>>
    in the equation for <with|mode|math|<wide|f|~>>, in the direction of the
    arrows. The horizontal direction of the arrows corresponds to the slope
    of the starting exponent<nbsp><with|mode|math|0>. Moreover, the fact that
    <with|mode|math|1> is a starting term corresponds to the fact that the
    coefficient of the lowest left-most induced point vanishes.
  </big-figure>

  <no-indent>Notice that the Newton polynomials can again be read off from
  the Newton polygon. Indeed, when labeling each point
  <with|mode|math|(f<rsup|i>,z<rsup|\<mu\>>)> by the coefficient of
  <with|mode|math|z<rsup|\<mu\>>> in <with|mode|math|P<rsub|i>>, the
  coefficients of <with|mode|math|N<rsub|P,z<rsup|\<mu\>>>> are precisely the
  coefficients on the edge with slope <with|mode|math|\<mu\>>.

  Given a starting term <with|mode|math|c*z<rsup|\<mu\>>\<in\>\<bbb-C\>*z<rsup|\<bbb-Q\>>>,
  we can now consider the equation <with|mode|math|<tP>(<tf>)=0> which is
  obtained from (<reference|N:New:ex1>), by substituting
  <with|mode|math|c*z<rsup|\<mu\>>+<tf>> for <with|mode|math|f>, and where
  <with|mode|math|<tf>> satisfies the asymptotic constraint
  <with|mode|math|<wide|f|~>\<prec\>z<rsup|\<mu\>>>. For instance, if
  <with|mode|math|c*z<rsup|\<mu\>>=1*z<rsup|0>>, then we obtain:

  <\eqnarray*>
    <tformat|<table|<row|<cell|<tP>(<tf>)>|<cell|=>|<cell|z<rsup|3>*<tf><rsup|6>+(6z<rsup|3>)*<tf><rsup|5>+
    (15*z<rsup|3>+5*z<rsup|4>+1)*<tf><rsup|4>+>>|<row|<cell|>|<cell|>|<cell|(20*z<rsup|3>+10*z<rsup|4>+2)*<tf><rsup|3>+(15*z<rsup|3>+10*z<rsup|4>+<no-break>1)*<tf><rsup|2>+>>|<row|<cell|>|<cell|>|<cell|<left|(>6*z<rsup|3>+5*z<rsup|4>+<with|math-display|false|<frac|z|1-z<rsup|2>>><right|)>*<tf>+z<rsup|4>+z<rsup|3>+<with|math-display|false|<frac|z<rsup|4>+z<rsup|3>+z|1-z<rsup|2>>>=0<space|2em>(<wide|f|~>\<prec\>1)<eq-number><label|N:New:ex1c>>>>>
  </eqnarray*>

  The Newton polygon associated to (<reference|N:New:ex1c>) is illustrated at
  the right hand side of figure<nbsp><reference|Newpolfig>. It remains to be
  shown that we may solve (<reference|N:New:ex1c>) by using the same method
  in a recursive way.

  <subsection|Equations with asymptotic constraints and refinements>

  First of all, since the new equation (<reference|N:New:ex1c>) comes with
  the asymptotic side-condition <with|mode|math|<wide|f|~>\<prec\>1>, it is
  convenient to study polynomial equations with asymptotic side-conditions

  <\equation>
    <label|ex-aspol-eq>P(f)=0<space|1em>(f\<prec\>z<rsup|\<nu\>>)
  </equation>

  in a systematic way. The case of usual polynomial equations is recovered by
  allowing <with|mode|math|\<nu\>=\<um\>\<infty\>>. In order to solve
  (<reference|ex-aspol-eq>), we now only keep those starting monomials
  <with|mode|math|z<rsup|\<mu\>>> for <with|mode|math|P(f)=0> which satisfy
  the asymptotic side condition <with|mode|math|z<rsup|\<mu\>>\<prec\>z<rsup|\<nu\>>>,
  <abbr|i.e.> <with|mode|math|\<mu\>\<gtr\>\<nu\>>.

  The highest degree of <with|mode|math|N<rsub|P,z<rsup|\<mu\>>>> for a
  monomial <with|mode|math|z<rsup|\<mu\>>\<prec\>z<rsup|\<nu\>>> is called
  the Newton degree of (<reference|ex-aspol-eq>). If
  <with|mode|math|d\<gtr\>0>, then <with|mode|math|P> is either divisible by
  <with|mode|math|f> (and <with|mode|math|f=0> is a solution to
  (<reference|ex-aspol-eq>)), or (<reference|ex-aspol-eq>) admits a starting
  monomial (and we can carry out one step of the above resolution procedure).
  If <with|mode|math|d=0>, then (<reference|ex-aspol-eq>) admits no
  solutions.

  <\big-figure|<postscript|figures/Npol3.ps|*3/5|*3/5||||><space|4spc><postscript|figures/Npol4.ps|*3/5|*3/5||||>>
    <label|Newpolfig2>At the left-hand side, we have illustrated the Newton
    polygon for the asymptotic equation <with|mode|math|P(f)=0<space|1.2spc>(f\<prec\>z<rsup|1/2>)>.
    The dashed line corresponds to the slope <with|mode|math|1/2> and the
    edges of the Newton polygon with slope <with|mode|math|<op|\<gtr\>> 1/2>
    have been highlighted. Notice that the Newton degree <with|mode|math|d=2>
    corresponds to the first coordinate of the rightmost point on an edge
    with slope <with|mode|math|<op|\<gtr\>> 1/2>. At the right-hand side, we
    have shown the ``pivoting'' effect around the origin of the substitution
    <with|mode|math|f=z<rsup|1/2>*<wide|f|~>> on the Newton polygon.
  </big-figure>

  <\remark>
    Graphically speaking, the starting exponents for
    (<reference|ex-aspol-eq>) correspond to to sufficiently steep slopes in
    the Newton polygon (see figure <reference|Newpolfig2>). Using a
    substitution <with|mode|math|f=z<rsup|\<nu\>>*<wide|f|~>>, the equation
    (<reference|ex-aspol-eq>) may always be transformed into an equation

    <\equation*>
      <wide|P|~>(<wide|f|~>)=0<space|1em>(<wide|f|~>\<prec\>1)
    </equation*>

    with a normalized asymptotic side-condition (the case
    <with|mode|math|\<nu\>=\<um\>\<infty\>> has to be handled with some
    additional care). Such transformations, called <em|multiplicative
    conjugations><bi-index*|multiplicative|conjugate>, will be useful in
    chapter <reference|ade-chap>, and their effect on the Newton polygon is
    illustrated in figure <reference|Newpolfig2>.
  </remark>

  Given a starting term <with|mode|math|\<varphi\>=\<tau\>=c*z<rsup|\<mu\>>>
  or a more general series <with|mode|math|\<varphi\>=c*z<rsup|\<mu\>>+\<cdots\>\<in\>\<bbb-C\><gb|z<rsup|\<bbb-Q\>>>>,
  we next consider the transformation

  <\equation>
    <label|ex-refinement>f=\<varphi\>+<tf><space|1em>(<wide|f|~>\<prec\>z<rsup|<wide|\<nu\>|~>>),
  </equation>

  with <with|mode|math|z<rsup|<wide|\<nu\>|~>>\<preccurlyeq\>z<rsup|\<mu\>>>,
  which transforms (<reference|ex-aspol-eq>) into a new asymptotic polynomial
  equation

  <\equation>
    <label|ex-aspol-eq2><wide|P|~>(<wide|f|~>)=0<space|1em>(<wide|f|~>\<prec\>z<rsup|<wide|\<nu\>|~>>).
  </equation>

  Transformations like (<reference|ex-refinement>) are called
  <em|refinements><index|refinement>. A refinement is said to be
  <em|admissible><bi-index*|admissible|refinement>, if the Newton degree of
  (<reference|ex-aspol-eq2>) does not vanish.

  Now the process of computing starting terms and their corresponding
  refinements is generally infinite and even transfinite. <em|A priori>, the
  process therefore only generates an infinite number of necessary conditions
  for Puiseux series <with|mode|math|f> to
  satisfy<nbsp>(<reference|ex-aspol-eq>). In order to really <em|solve>
  (<reference|ex-aspol-eq>), we have to prove that, after a finite number of
  steps of the Newton polygon method, and whatever starting terms we chose
  (when we have a choice), we obtain an asymptotic polynomial equation with a
  unique solution. In the next section, we will prove an implicit function
  theorem which guarantees the existence of such a unique solution for
  equations of Newton degree one. Such equations will be said to be
  <em|quasi-linear><bi-index|quasi-linear|equation>.

  Returning to our example equation (<reference|N:New:ex1>), it can be
  checked that each of the refinements

  <\equation*>
    <tabular|<tformat|<table|<row|<cell|f>|<cell|=>|<cell|\<um\>z<rsup|2>+<wide|f|~>>|<cell|(<wide|f|~>\<prec\>z<rsup|2>);>>|<row|<cell|f>|<cell|=>|<cell|\<um\>z+<wide|f|~>>|<cell|(<wide|f|~>\<prec\>z);>>|<row|<cell|f>|<cell|=>|<cell|\<um\>\<mathi\>*z<rsup|\<um\>3/2>+<wide|f|~><space|1em>>|<cell|(<wide|f|~>\<prec\>z<rsup|\<um\><with|math-display|false|3/2>>);>>|<row|<cell|f>|<cell|=>|<cell|\<mathi\>*z<rsup|\<um\>3/2>+<wide|f|~>>|<cell|(<wide|f|~>\<prec\>z<rsup|\<um\><with|math-display|false|3/2>>)>>>>>
  </equation*>

  leads to a quasi-linear equation in <with|mode|math|<wide|f|~>>. The case

  <equation*|f=1+<tf><hspace|1fn>(<wide|f|~>\<prec\>1)>

  leads to an equation of Newton degree <with|mode|math|2> (it will be shown
  later that the Newton degree of (<reference|ex-aspol-eq2>) coincides with
  the multiplicity of <with|mode|math|c> as a root of
  <with|mode|math|N<rsub|P,z<rsup|\<mu\>>>>). Therefore, the last case
  necessitates one more step of the Newton polygon method:

  <\equation*>
    <tabular|<tformat|<table|<row|<cell|<wide|f|~>>|<cell|=>|<cell|\<um\>\<mathi\>*<sqrt|z>+<wide|<wide|f|~>|~><space|2spc>>|<cell|(<wide|<wide|f|~>|~>\<prec\>z<rsup|1/2>);>>|<row|<cell|<wide|f|~>>|<cell|=>|<cell|\<mathi\>*<sqrt|z>+<wide|<wide|f|~>|~>>|<cell|(<wide|<wide|f|~>|~>\<prec\>z<rsup|1/2>).>>>>>
  </equation*>

  For both refinements, it can be checked that the asymptotic equation in
  <with|mode|math|<wide|<wide|f|~>|~>> is quasi-linear. Hence, after a finite
  number of steps, we have obtained a complete description of the set of
  solutions to (<reference|N:New:ex1>). The first terms of these solutions
  are as follows:

  <eqnarray*|<tformat|<table|<row|<cell|f<rsub|I>>|<cell|=>|<cell|\<um\>z<rsup|2>-2*z<rsup|3>-4*z<rsup|4>-13*z<rsup|5>-50*z<rsup|6>+O(z<rsup|7>);>>|<row|<cell|f<rsub|I*I>>|<cell|=>|<cell|\<um\>z+3*z<rsup|2>-8*z<rsup|3>+46*z<rsup|4>-200*z<rsup|5>+O(z<rsup|6>);>>|<row|<cell|f<rsub|I*I*I>>|<cell|=>|<cell|1-\<mathi\>*z<rsup|1/2>+<with|math-display|false|<frac|1|2>>*z+<with|math-display|false|<frac|5*\<mathi\>|8>>*z<rsup|3/2>-z<rsup|2>+O(z<rsup|5/2>);>>|<row|<cell|f<rsub|I*V>>|<cell|=>|<cell|1+\<mathi\>*z<rsup|1/2>+<with|math-display|false|<frac|1|2>>*z-<with|math-display|false|<frac|5*\<mathi\>|8>>*z<rsup|3/2>-z<rsup|2>+O(z<rsup|5/2>);>>|<row|<cell|f<rsub|V>>|<cell|=>|<cell|\<um\>\<mathi\>*z<rsup|\<um\>3/2>-1-<with|math-display|false|<frac|1|2>>*z-\<mathi\>*z<rsup|3/2>-<with|math-display|false|<frac|\<mathi\>|2>>*z<rsup|5/2>+O(z<rsup|3>);>>|<row|<cell|f<rsub|V*I>>|<cell|=>|<cell|\<mathi\>*z<rsup|\<um\>3/2>-1-<with|math-display|false|<frac|1|2>>*z+\<mathi\>*z<rsup|3/2>+<with|math-display|false|<frac|\<mathi\>|2>>*z<rsup|5/2>+O(z<rsup|3>).>>>>>

  <subsection|Almost double roots><label|Npol-almost-mult>

  Usually the Newton degrees rapidly decreases during refinements and we are
  quickly left with only quasi-linear equations. However, in the presence of
  almost multiple roots<subindex|root|almost multiple>, the Newton degree may
  remain bigger than two for quite a while. Consider for instance the
  equation

  <equation|<label|N:New:ex2><left|(> f- <frac|1|1-z> <right|)><rsup|2>=
  \<varepsilon\><rsup|2>>

  over <with|mode|math|\<bbb-C\><gb|z;\<varepsilon\>>>, with
  <with|mode|math|z\<prec\>1> and <with|mode|math|\<varepsilon\>\<prec\>1>.
  This equation has Newton degree <with|mode|math|2>, and after
  <with|mode|math|n> steps of the ordinary Newton polygon method, we obtain
  the equation

  <\equation*>
    <left|(> <wide|f|~>- <frac|z<rsup|n>|1-z> <right|)><rsup|2>=
    \<varepsilon\><rsup|2><space|1em>(<wide|f|~>\<prec\>z<rsup|n-1>),
  </equation*>

  which still has Newton degree <with|mode|math|2>. In order to enforce
  termination, an additional trick is applied: consider the first derivative

  <equation*|2*f-<frac|2|1-z>= 0>

  of the equation (<reference|N:New:ex2>) <abbr|w.r.t.> <with|mode|math|f>.
  This derived equation is quasi-linear, so it admits a unique solution

  <equation*|\<varphi\>=<frac|1|1-z>.>

  Now, instead of performing the usual refinement <with|mode|math|f= 1+
  <tf><space|1.2spc>(<wide|f|~>\<prec\>1)> in the original
  equation<nbsp>(<reference|N:New:ex2>), we perform refinement

  <equation*|f= \<varphi\>+<tf><space|1em>(<wide|f|~>\<prec\>1).>

  This yields the equation

  <equation*|<tf><rsup|2>= \<varepsilon\><rsup|2>
  <hspace|1fn>(<wide|f|~>\<prec\>1).>

  Applying one more step of the Newton polygon method yields the admissible
  refinements

  <\equation*>
    <tabular|<tformat|<table|<row|<cell|<wide|f|~>>|<cell|=>|<cell|\<um\>\<varepsilon\>+<wide|<wide|f|~>|~><space|1em>>|<cell|(<wide|f|~>\<prec\>\<varepsilon\>);>>|<row|<cell|<wide|f|~>>|<cell|=>|<cell|\<varepsilon\>+<wide|<wide|f|~>|~>>|<cell|(<wide|f|~>\<prec\>\<varepsilon\>).>>>>>
  </equation*>

  In both cases, we obtain a quasi-linear equation in
  <with|mode|math|<wide|<wide|f|~>|~>>:

  <\equation*>
    <tabular|<tformat|<table|<row|<cell|\<um\>2*\<varepsilon\>*<wide|<wide|f|~>|~>+<wide|<wide|f|~>|~><rsup|2>>|<cell|=>|<cell|0<space|1em>>|<cell|(<wide|f|~>\<prec\>\<varepsilon\>);>>|<row|<cell|2*\<varepsilon\>*<wide|<wide|f|~>|~>+<wide|<wide|f|~>|~><rsup|2>>|<cell|=>|<cell|0>|<cell|(<wide|f|~>\<prec\>\<varepsilon\>).>>>>>
  </equation*>

  In section <reference|Nddec>, we will show that this trick applies in
  general, and that the resulting method always yields a complete description
  of the solution set after a finite number of steps.

  <remark|The idea of using repeated differentiation in order to handle
  almost multiple solutions is old <cite|Sm1875> and has been used in
  computer algebra before <no-break><cite|Chis86|Gri91>. Our contribution has
  been to incorporate it directly into the Newton polygon process, as will be
  shown in more detail in section <no-break><reference|Nddec>.>

  <section|The implicit series theorem><label|impl-ser-sec>

  In the previous section, we have stressed the particular importance of
  quasi-linear equations when solving asymptotic polynomial equations. In
  this section, we will prove an implicit series theorem for polynomial
  equations. In the next section, we will apply this theorem to show that
  quasi-linear equations admit unique solutions. The implicit series theorem
  admits several proofs (see the exercises). The proof we present here uses a
  powerful syntactic technique, which will be generalized in chapter
  <no-break><reference|gbop>.

  <\theorem>
    <label|isth>Let <with|mode|math|C> be a ring and
    <with|mode|math|\<frak-M\>> a monomial monoid. Consider the polynomial
    equation

    <equation|P<rsub|n>*f<rsup|n>+\<cdots\>+P<rsub|0>=0<label|implpoleq>>

    with coefficients <with|mode|math|P<rsub|0>,\<ldots\>,P<rsub|n>\<in\>C<gb|\<frak-M\><rsub|\<preccurlyeq\>>>>,
    such that <with|mode|math|P<rsub|0,1>=0> and
    <with|mode|math|P<rsub|1,1>\<in\>C<rsup|\<ast\>>>. Then
    <with|font-shape|right|(<reference|implpoleq>)> admits a unique solution
    in <with|mode|math|C<gb|\<frak-M\><rsub|\<prec\>>>>.
  </theorem>

  <\proof>
    Since <with|mode|math|P<rsub|1,1>\<in\>C<rsup|\<ast\>>>, the series
    <with|mode|math|P<rsub|1>> is invertible in
    <with|mode|math|C<gb|\<frak-M\><rsub|\<preccurlyeq\>>>>. Modulo division
    of <no-break>(<reference|implpoleq>) by <with|mode|math|P<rsub|1>>, we
    may therefore assume without loss of generality that
    <with|mode|math|P<rsub|1>=1>. Setting
    <with|mode|math|Q<rsub|i>=\<um\>P<rsub|i>> for all
    <with|mode|math|i\<neq\>1>, we may then rewrite (<reference|implpoleq>)
    as

    <equation|f=Q<rsub|0>+Q<rsub|2>*f<rsup|2>+\<cdots\>+Q<rsub|n>*f<rsup|n>.<label|itpoleq>>

    Now consider the set <with|mode|math|<value|rsT>> of trees with nodes of
    arities in <with|mode|math|{0,2,\<ldots\>,n}> and such that each node of
    arity <with|mode|math|i> is labeled by a monomial in <with|mode|math|supp
    Q<rsub|i>>. To each such tree

    <equation*|t=<tree|\<frak-v\>|t<rsub|1>|\<cdots\>|t<rsub|i>>\<in\><value|rsT>>

    we recursively associate a coefficient <with|mode|math|c<rsub|t>\<in\>C>
    and a monomial <with|mode|math|\<frak-m\><rsub|t>\<in\>\<frak-M\>> by

    <eqnarray*|<tformat|<table|<row|<cell|c<rsub|t>>|<cell|=>|<cell|Q<rsub|i,\<frak-v\>>*c<rsub|t<rsub|1>>*\<cdots\>*c<rsub|t<rsub|i>>;>>|<row|<cell|\<frak-m\><rsub|t>>|<cell|=>|<cell|\<frak-v\>*\<frak-m\><rsub|t<rsub|1>>*\<cdots\>*\<frak-m\><rsub|t<rsub|i>>.>>>>>

    Now we observe that each of these monomials
    <with|mode|math|\<frak-m\><rsub|t>> is infinitesimal, with

    <equation|<label|itbound>\<frak-m\><rsub|t>\<in\>(supp
    Q<rsub|0>)\<cdot\><left|(>supp Q<rsub|0>\<cup\>supp
    Q<rsub|2>\<cup\>\<cdots\>\<cup\>supp Q<rsub|n><right|)><rsup|\<ast\>>.>

    Hence the mapping <with|mode|math|t\<mapsto\>\<frak-m\><rsub|t>> is
    strictly increasing, when <with|mode|math|<value|rsT>> is given the
    embeddability ordering from section <reference|Kruskal-th>. From
    Kruskal's theorem, it follows that the family
    <with|mode|math|(c<rsub|t>*\<frak-m\><rsub|t>)<rsub|t\<in\><value|rsT>>>
    is well-based and even grid-based, because of (<reference|itbound>). We
    claim that <with|mode|math|f=<big|sum><rsub|t\<in\><value|rsT>>c<rsub|t>*\<frak-m\><rsub|t>>
    is the unique solution to <no-break>(<reference|itpoleq>).

    First of all, <with|mode|math|f> is indeed a solution to
    (<reference|itpoleq>), since

    <eqnarray*|<tformat|<table|<row|<cell|f>|<cell|=>|<cell|<big|sum><rsub|i\<in\>{0,2,\<ldots\>,n}><big|sum><rsub|\<frak-v\>\<in\>supp
    Q<rsub|i>><big|sum><rsub|t<rsub|1>,\<ldots\>,t<rsub|i>\<in\><value|rsT>>c<rsub|<tree|\<frak-v\>|t<rsub|1>|\<cdots\>|t<rsub|i>>>*\<frak-m\><rsub|<tree|\<frak-v\>|t<rsub|1>|\<cdots\>|t<rsub|i>>>>>|<row|<cell|>|<cell|=>|<cell|<big|sum><rsub|i\<in\>{0,2,\<ldots\>,n}><big|sum><rsub|\<frak-v\>\<in\>supp
    Q<rsub|i>><big|sum><rsub|t<rsub|1>,\<ldots\>,t<rsub|i>\<in\><value|rsT>>(Q<rsub|i,\<frak-v\>>*\<frak-v\>)*(c<rsub|t<rsub|1>>*\<frak-m\><rsub|t<rsub|1>>)*\<cdots\>*(c<rsub|t<rsub|i>>*\<frak-m\><rsub|t<rsub|i>>)>>|<row|<cell|>|<cell|=>|<cell|<big|sum><rsub|i\<in\>{0,2,\<ldots\>,n}><left|(><big|sum><rsub|\<frak-v\>\<in\>supp
    Q<rsub|i>><rsup|>Q<rsub|i,\<frak-v\>>*\<frak-v\><right|)>*<left|(><big|prod><rsub|j=1><rsup|i><big|sum><rsub|t<rsub|j>\<in\><value|rsT>>c<rsub|t<rsub|j>>*\<frak-m\><rsub|t<rsub|j>><right|)>>>|<row|<cell|>|<cell|=>|<cell|<big|sum><rsub|i\<in\>{0,2,\<ldots\>,n}>Q<rsub|i>*f<rsup|i>=Q<rsub|0>+Q<rsub|2>*f<rsup|2>+\<cdots\>+Q<rsub|n>*f<rsup|n>.>>>>>

    In order to see that <with|mode|math|f> is the unique solution to
    (<reference|implpoleq>), consider the polynomial
    <with|mode|math|R(\<delta\>)=P(f+\<delta\>)>. Since
    <with|mode|math|f\<prec\>1>, we have <with|mode|math|R<rsub|i>=P<rsub|i>+o(1)>
    for all <with|mode|math|i>, whence in particular
    <with|mode|math|R<rsub|1>=1+o(1)>. Furthermore, <with|mode|math|P(f)=0>
    implies <with|mode|math|R<rsub|0>=0>. Now assume that
    <with|mode|math|g\<prec\>1> were another root of <with|mode|math|P>. Then
    <with|mode|math|\<delta\>=g-f\<prec\>1> would be a root of
    <with|mode|math|R>, so that

    <equation|\<delta\>=(R<rsub|1>+R<rsub|2>*\<delta\>+\<cdots\>+R<rsub|n-1>*\<delta\><rsup|n-1>)<rsup|\<um\>1>*R(\<delta\>)=0,>

    since <with|mode|math|R<rsub|1>+R<rsub|2>*\<delta\>+\<cdots\>+R<rsub|n-1>*\<delta\><rsup|n-1>=1+o(1)>
    is invertible.
  </proof>

  <\exercise>
    Generalize theorem <reference|isth> to the case when
    (<reference|implpoleq>) is replaced by

    <equation*|P<rsub|0>+P<rsub|1>*f+P<rsub|2>*f<rsup|2>+\<cdots\>=0,>

    where <with|mode|math|(P<rsub|i>)<rsub|i\<in\>\<bbb-N\>>\<in\>C<gb|\<frak-M\><rsub|\<preccurlyeq\>>>>
    is a grid-based family with <with|mode|math|P<rsub|0,1>=0> and
    <with|mode|math|P<rsub|1,1>\<in\>C<rsup|\<ast\>>>.
  </exercise>

  <exercise|Give an alternative proof of theorem <reference|isth>, using the
  fact that (<reference|itpoleq>) admits a unique power series solution in
  <with|mode|math|\<bbb-Z\>[[Q<rsub|2>*Q<rsub|0>,\<ldots\>,Q<rsub|n>*Q<rsub|0><rsup|n-1>]]*Q<rsub|0>>,
  when considered as an equation with coefficients in
  <with|mode|math|\<bbb-Z\>[[Q<rsub|0>,Q<rsub|2>,\<ldots\>,Q<rsub|n>]]>.>

  <exercise|Assuming that <with|mode|math|\<frak-M\>> is totally ordered,
  give yet another alternative proof of theorem <reference|isth>, by
  computing the terms of the unique solution by transfinite induction.>

  <\exercise>
    Let <with|mode|math|C\<langle\>\<langle\>z<rsub|1>,\<ldots\>,z<rsub|n>\<rangle\>\<rangle\>>
    denote the ring of non-commutative power series in
    <with|mode|math|z<rsub|1>,\<ldots\>,<no-break>z<rsub|n>> over
    <with|mode|math|C>. Consider the equation

    <\equation>
      <label|nc-impl-eq>f(g(z<rsub|1>,\<ldots\>,z<rsub|n>),z<rsub|1>,\<ldots\>,z<rsub|n>)=0
    </equation>

    with <with|mode|math|f\<in\>C\<langle\>\<langle\>y,z<rsub|1>,\<ldots\>,z<rsub|n>\<rangle\>\<rangle\>>,
    <with|mode|math|f<rsub|1>=0> and invertible <with|mode|math|f<rsub|y>>.
    Prove that (<reference|nc-impl-eq>) admits a unique infinitesimal
    solution <with|mode|math|g\<in\>C\<langle\>\<langle\>z<rsub|1>,\<ldots\>,z<rsub|n>\<rangle\>\<rangle\>>.
  </exercise>

  <section|The Newton polygon method><label|N:Newton:alg>

  <subsection|Newton polynomials and Newton degree>

  Let <with|mode|math|C> be a constant field of characteristic zero and
  <with|mode|math|\<frak-M\>> a totally ordered monomial group with
  <with|mode|math|\<bbb-Q\>>-powers. Consider the <em|asymptotic polynomial
  equation><subindex|asymptotic|equation><subindex|equation|asymptotic>

  <equation|<label|N:poleq>P<rsub|n>*f<rsup|n>+\<cdots\>+P<rsub|0>=0<hspace|1fn>(f
  \<prec\>\<frak-v\>),>

  with coefficients in <with|mode|math|C<gb|\<frak-M\>>> and
  <with|mode|math|\<frak-v\>\<in\>\<frak-M\>>. In order to capture ordinary
  polynomial equations, we will also allow
  <with|mode|math|\<frak-v\>=\<top\><rsub|\<frak-M\>>>, where
  <with|mode|math|\<top\><rsub|\<frak-M\>>> is a formal monomial with
  <with|mode|math|\<top\><rsub|\<frak-M\>>\<succ\>\<frak-M\>>. A <em|starting
  monomial><bi-index|starting|monomial> of <with|mode|math|f> relative to
  (<reference|N:poleq>) is a monomial <with|mode|math|\<frak-m\>\<prec\>\<frak-v\>>
  in <with|mode|math|\<frak-M\>>, such that there exist
  <with|mode|math|0\<leqslant\>i\<less\>j\<leqslant\>n> and
  <with|mode|math|\<frak-n\>\<in\>\<frak-M\>> with
  <with|mode|math|P<rsub|i>*\<frak-m\><rsup|i>\<asymp\>P<rsub|j>*\<frak-m\><rsup|j>\<asymp\>\<frak-n\>>
  and <with|mode|math|P<rsub|k>*\<frak-m\><rsup|k>\<preccurlyeq\>\<frak-n\>>
  for all other <no-break><with|mode|math|k>. To such a starting monomial
  <no-break><with|mode|math|\<frak-m\>> we associate the
  equation<glossary-explain|<with|mode|math|N<rsub|P, \<frak-m\>>>|Newton
  polynomial associated to <with|mode|math|\<frak-m\>>>

  <equation|<label|N:domeq> N<rsub|P, \<frak-m\>>(c)=
  P<rsub|d,\<frak-n\>/\<frak-m\><rsup|d>>*c<rsup|d>+\<cdots\>+P<rsub|0,\<frak-n\>>=0,>

  and <with|mode|math|N<rsub|P, \<frak-m\>>> is called the <em|Newton
  polynomial><bi-index|Newton|polynomial> associated to
  <with|mode|math|\<frak-m\>>. A <em|starting term><bi-index|starting|term>
  of <with|mode|math|f> relative to (<reference|N:poleq>) is a term
  <with|mode|math|\<tau\>=c*\<frak-m\>>, where <with|mode|math|\<frak-m\>> is
  a starting monomial of <with|mode|math|f> relative to
  <no-break>(<reference|N:poleq>) and <with|mode|math|c\<in\>C<rsup|\<neq\>>>
  a non-zero root of <with|mode|math|N<rsub|P,\<frak-m\>>>. In that case, the
  <em|multiplicity><subsubindex|starting|term|multiplicity><subsubindex|term|starting|multiplicity><subindex|multiplicity|starting
  term> of <with|mode|math|\<tau\>> is defined to be the multiplicity of
  <with|mode|math|c> as a root of <with|mode|math|N<rsub|P,\<frak-m\>>>.
  Notice that there are only a finite number of starting terms relative to
  (<reference|N:poleq>).

  <proposition|<label|Newcoh>Let <with|mode|math|f> be a non-zero solution to
  <with|font-shape|right|(<reference|N:poleq>)>. Then
  <with|mode|math|\<tau\><rsub|f>> is a starting term for
  <with|font-shape|right|(<reference|N:poleq>)>.<htab|5mm><with|mode|math|\<box\>>>

  The <em|Newton degree><bi-index|Newton|degree> <with|mode|math|d> of
  (<reference|N:poleq>) is defined to be the largest degree of the Newton
  polynomial associated to a monomial <with|mode|math|\<frak-m\>\<prec\>\<frak-v\>>.
  In particular, if there exists no starting monomial relative to
  (<reference|N:poleq>), then the Newton degree equals the valuation of
  <with|mode|math|P> in<nbsp><with|mode|math|f>. If <with|mode|math|d=1>,
  then we say that (<reference|N:poleq>) is
  <em|quasi-linear><bi-index|quasi-linear|equation>. The previous proposition
  implies that (<reference|N:poleq>) does not admit any solution, if
  <with|mode|math|d=0>.

  <lemma|<label|N:polimpl>If <with|font-shape|right|(<reference|N:poleq>)> is
  quasi-linear, then it admits a unique solution in
  <with|mode|math|C<gb|\<frak-M\>>>.>

  <proof|If <with|mode|math|P<rsub|0>=0>, then our statement follows from
  proposition <reference|Newcoh>, since there are no starting monomials.
  Otherwise, our statement follows from theorem <no-break><reference|isth>,
  after substitution of <with|mode|math|f*\<frak-n\>> for <with|mode|math|f>
  in (<reference|N:poleq>), where <with|mode|math|\<frak-n\>> is chosen
  <with|mode|math|<op|\<preccurlyeq\>>>-maximal such that
  <with|mode|math|\<frak-d\><rsub|P<rsub|1>>\<succcurlyeq\>\<frak-d\><rsub|P<rsub|i>>*\<frak-n\><rsup|i-1>>
  for all <with|mode|math|i>, and after division of (<reference|N:poleq>) by
  <with|mode|math|\<frak-d\><rsub|P<rsub|1>>>.>

  <subsection|Decrease of the Newton degree during refinements><label|Nddec>

  A <em|refinement><index|refinement> is a change of variables together with
  the imposition of an asymptotic constraint:

  <equation|f=\<varphi\>+<tf><space|4spc>(<wide|f|~>\<prec\><wide|\<frak-v\>|~>),<label|ref>>

  where <with|mode|math|\<varphi\>\<prec\>\<frak-v\>> and
  <with|mode|math|<wide|\<frak-v\>|~>\<preccurlyeq\>\<frak-v\>>. Such a
  refinement transforms (<reference|N:poleq>) into an asymptotic polynomial
  equation in <with|mode|math|<tf>>:

  <equation|<label|N:newpoleq><tP><rsub|n>*<tf><rsup|n>+\<cdots\>+<tP><rsub|0>=0<hspace|1fn>(<tf>\<prec\><wide|\<frak-v\>|~>),>

  where

  <equation|<label|N:trdata><tP><rsub|i>=<frac|1|i!>*P<rsup|(i)>(\<varphi\>)=<big|sum><rsub|k=i><rsup|n><binom|k|i>*P<rsub|k>*\<varphi\><rsup|k-i>,>

  for each <with|mode|math|i>. We say that the refinement (<reference|ref>)
  is <em|admissible><bi-index*|admissible|refinement> if the Newton degree
  of<nbsp>(<reference|N:newpoleq>) is strictly positive.

  <\lemma>
    <label|N:rlem>Consider the refinement
    <with|font-shape|right|(<reference|ref>)> with
    <with|mode|math|<wide|\<frak-v\>|~>=\<frak-d\><rsub|\<varphi\>>>. Then

    <\enumerate-alpha>
      <item>The Newton degree of <with|font-shape|right|(<reference|N:newpoleq>)>
      coincides with the multiplicity of <with|mode|math|c> as a root of
      <no-break><with|mode|math|N<rsub|P,\<frak-m\>>>. In particular,
      <with|font-shape|right|(<reference|ref>)> is admissible if and only if
      <with|mode|math|c*\<frak-m\>> is a starting term for
      <with|font-shape|right|(<reference|N:poleq>)>.

      <item>The Newton degree of <with|font-shape|right|(<reference|N:newpoleq>)>
      is bounded by the Newton degree of <with|font-shape|right|(<reference|N:poleq>)>.
    </enumerate-alpha>
  </lemma>

  <\proof>
    Let <with|mode|math|d> be maximal such that
    <with|mode|math|P<rsub|d>*\<frak-m\><rsup|d>\<succcurlyeq\>P<rsub|i>*\<frak-m\><rsup|i>>
    for all <with|mode|math|i>, and denote
    <with|mode|math|\<frak-n\>=\<frak-d\>(P<rsub|d>)*\<frak-m\><rsup|d>>.
    Then <with|mode|math|d> is bounded by the Newton degree of
    (<reference|N:poleq>) and

    <eqnarray*|<tformat|<table|<row|<cell|<tP><rsub|i>>|<cell|=>|<cell|<frac|1|i!>*<big|sum><rsub|k=i><rsup|n><binom|k|i>*P<rsub|k>*\<varphi\><rsup|k-i>>>|<row|<cell|>|<cell|=>|<cell|<frac|1|i!>*<big|sum><rsub|k=i><rsup|n><binom|k|i>*(P<rsub|k,\<frak-n\>*\<frak-m\><rsup|\<um\>k>>+o(1))*\<frak-n\>*\<frak-m\><rsup|\<um\>k>*(c+o(1))<rsup|k-i>*\<frak-m\><rsup|k-i>>>|<row|<cell|>|<cell|=>|<cell|<frac|1|i!>*N<rsub|P,
    \<frak-m\>><rsup|(i)>(c)*\<frak-n\>*\<frak-m\><rsup|i>+o(\<frak-n\>*\<frak-m\><rsup|i>),>>>>>

    for all <with|mode|math|i>. In particular, denoting the multiplicity of
    <with|mode|math|c> as a root of <with|mode|math|N<rsub|P,\<frak-m\>>> by
    <with|mode|math|<wide|d|~>>, we have <with|mode|math|<tP><rsub|<wide|d|~>>\<asymp\>\<frak-n\>*\<frak-m\><rsup|\<um\><wide|d|~>>>.
    Moreover, for all <with|mode|math|i\<geqslant\><wide|d|~>>, we have
    <with|mode|math|<tP><rsub|i>\<preccurlyeq\>\<frak-n\>*\<frak-m\><rsup|\<um\>i>>.
    Hence, for any <with|mode|math|i\<gtr\><wide|d|~>> and
    <with|mode|math|<wide|\<frak-m\>|~> \<prec\>\<frak-m\>>, we have
    <with|mode|math|<tP><rsub|i>*<wide|\<frak-m\>|~><rsup|i>\<prec\><tP><rsub|<wide|d|~>>*<wide|\<frak-m\>|~><rsup|<wide|d|~>>>.
    This shows that the Newton degree of (<reference|N:newpoleq>) is at most
    <with|mode|math|<wide|d|~>>.

    Let us now show that the Newton degree of
    <with|font-shape|right|(<reference|N:newpoleq>)> is precisely
    <with|mode|math|<wide|d|~>>. Choose <with|mode|math|<wide|\<frak-m\>|~>\<prec\>\<frak-m\>>
    large enough, so that

    <equation*|<wide|\<frak-m\>|~>\<succcurlyeq\><sqrt|<frac|\<frak-d\><rsub|<tP><rsub|i>(<tf>)>|\<frak-d\><rsub|<tP><rsub|<wide|d|~>>(<tf>)>>|<wide|d|~>-i>>

    for all <with|mode|math|i\<less\><wide|d|~>>. Then <with|mode|math|deg
    N<rsub|<wide|P|~>,<wide|\<frak-m\>|~>>=<wide|d|~>>.
  </proof>

  If one step of the Newton polygon method does not suffice to decrease the
  Newton degree, then two steps do, when applying the trick from the next
  lemma:

  <\lemma>
    <label|N:pdouble>Let <with|mode|math|d> be the Newton degree of
    <with|font-shape|right|(<reference|N:poleq>)>. If <with|mode|math|f>
    admits a unique starting monomial <with|mode|math|\<frak-m\>> and
    <with|mode|math|N<rsub|P, \<frak-m\>>> a unique root <with|mode|math|c>
    of multiplicity <with|mode|math|d>, then

    <\enumerate-alpha>
      <item>The equation

      <equation|P<rsup|(d-1)>(\<varphi\>)=0<space|4spc>(\<varphi\>\<prec\>\<frak-v\>)<label|derpol>>

      is quasi-linear and its unique solution satisfies
      <with|mode|math|\<varphi\>=c*\<frak-m\>+o(\<frak-m\>)>.

      <item>The Newton degree of any refinement

      <equation*|<tf>=<wide|\<varphi\>|~>+<wide|<wide|f|~>|~><hspace|1fn>(<wide|<wide|f|~>|~>\<prec\><wide|<wide|\<frak-v\>|~>|~>)>

      relative to <with|font-shape|right|(<reference|N:newpoleq>)> with
      <with|mode|math|<wide|<wide|\<frak-v\>|~>|~>=\<frak-d\><rsub|<wide|<wide|\<varphi\>|~>|~>>>
      is strictly inferior to <with|mode|math|d>.
    </enumerate-alpha>
  </lemma>

  <\proof>
    Notice first that <with|mode|math|N<rsub|P<rprime|'>,\<frak-m\>>=N<rprime|'><rsub|P,\<frak-m\>>>
    for all polynomials <with|mode|math|P> and monomials
    <with|mode|math|\<frak-m\>>. Consequently, (<reference|derpol>) is
    quasi-linear and <with|mode|math|c> is a single root of
    <with|mode|math|N<rsub|P<rsup|(d-1)>,\<frak-m\>>>. This proves
    <no-break>(<with|font-shape|italic|a>).

    As to (<em|b>), we first observe that
    <with|mode|math|<tP><rsub|d-1>=P<rsup|(d-1)>(\<varphi\>)=0>. Given
    <with|mode|math|<wide|\<frak-m\>|~>\<prec\><wide|\<frak-v\>|~>>, it
    follows that <with|mode|math|N<rsub|<tP>, \<frak-m\>, d-1>=0>. In
    particular, there do not exist <with|mode|math|\<alpha\>\<neq\>0,\<beta\>\<neq\>0>
    with <with|mode|math|N<rsub|<tP>, <wide|\<frak-m\>|~>>(<wide|c|~>)=\<alpha\>*(<wide|c|~>-\<beta\>)<rsup|d>>.
    In other words, <with|mode|math|N<rsub|<tP>, <wide|\<frak-m\>|~>>> does
    not admit roots of multiplicity <with|mode|math|d>. We conclude by
    lemma<nbsp><reference|N:rlem>.
  </proof>

  <subsection|Resolution of asymptotic polynomial equations>

  <theorem|<label|alg-cl>Let <with|mode|math|C> be an algebraically closed
  field of characteristic zero and <with|mode|math|\<frak-M\>> a totally
  ordered monomial group with <with|mode|math|\<bbb-Q\>>-powers. Then
  <with|mode|math|C<gb|\<frak-M\>>> is algebraically closed.>

  <\proof>
    Consider the following algorithm:<vspace|1fn>

    <no-indent><with|font-series|bold|Algorithm>
    <with|font-family|tt|polynomial_solve><index|<verbatim|polynomial_solve>><next-line><with|font-series|bold|Input:>
    An asymptotic polynomial equation (<reference|N:poleq>).<next-line><with|font-series|bold|Output:
    >The set of solutions to (<reference|N:poleq>).

    <surround||<vspace|1fn>|<\enumerate>
      <item>Compute the starting terms <with|mode|math|c<rsub|1>*\<frak-m\><rsub|1>,\<ldots\>,c<rsub|\<nu\>>*\<frak-m\><rsub|\<nu\>>>
      of <with|mode|math|f> relative to (<reference|N:poleq>).

      <item>If <with|mode|math|\<nu\>=1> and <with|mode|math|c<rsub|1>> is a
      root of multiplicity <with|mode|math|d> of
      <with|mode|math|N<rsub|P,\<frak-m\><rsub|1>>>, then let
      <with|mode|math|\<varphi\>> be the unique solution to
      (<reference|derpol>). Refine (<reference|ref>) and apply
      <with|font-family|tt|polynomial_solve> to (<reference|N:newpoleq>).
      Return the so obtained solutions to (<reference|N:poleq>).

      <item>For each <with|mode|math|1\<leqslant\>i\<leqslant\>\<nu\>>,
      refine <with|mode|math|f= c<rsub|i>*\<frak-m\><rsub|i>+<tf><hspace|1fn>(<tf>\<prec\>\<frak-m\><rsub|i>)>
      and apply <with|font-family|tt|polynomial_solve> to the new equation in
      <with|mode|math|<wide|f|~>>. Collect and return the so obtained
      solutions to <no-break>(<reference|N:poleq>), together with
      <with|mode|math|0>, if <with|mode|math|P> is divisible by
      <with|mode|math|f>.
    </enumerate>>

    <no-indent>The correctness of <with|font-family|tt|polynomial_solve> is
    clear; its termination follows from lemmas
    <no-break><reference|N:rlem>(<em|b>) and
    <no-break><reference|N:pdouble>(<em|b>). Since <with|mode|math|C> is
    algebraically closed, all Newton polynomials considered in the algorithm
    split over <with|mode|math|C>. Hence,
    <with|font-family|tt|polynomial_solve> returns <with|mode|math|d>
    solutions to (<reference|N:poleq>) in <with|mode|math|C<gb|\<frak-M\>>>,
    when counting with multiplicities. In particular, when taking
    <with|mode|math|\<frak-v\>=\<top\><rsub|\<frak-M\>>\<succ\>\<frak-M\>>,
    we obtain <with|mode|math|n> solutions, so
    <with|mode|math|C<gb|\<frak-M\>>> is algebraically closed.
  </proof>

  <corollary|<label|real-closed-th>Let <with|mode|math|C> be a real closed
  field and <with|mode|math|\<frak-M\>> a totally ordered monomial group with
  <with|mode|math|\<bbb-Q\>>-powers. Then <with|mode|math|C<gb|\<frak-M\>>>
  is real closed.>

  <\proof>
    By the theorem, a polynomial equation <with|mode|math|P(n)=0> of degree
    <with|mode|math|n> over <with|mode|math|C<gb|\<frak-M\>>> admits
    <with|mode|math|n> solutions in <with|mode|math|C[\<mathi\>]<gb|\<frak-M\>>>,
    when counting with multiplicities. Moreover, each root
    <with|mode|math|\<varphi\>\<in\>C[\<mathi\>]<gb|\<frak-M\>>\<setminus\>C<gb|\<frak-M\>>>
    is imaginary, because

    <equation*|\<mathi\>=<frac|\<varphi\>-Re \<varphi\>|Im
    \<varphi\>>\<in\>C<gb|\<frak-M\>>[\<varphi\>]>

    for such <with|mode|math|\<varphi\>>. Therefore all real roots of
    <with|mode|math|P> are in <with|mode|math|C<gb|\<frak-M\>>>.
  </proof>

  <corollary|<subindex|theorem|Newton-Puiseux>The field
  <with|mode|math|C<gb|z<rsup|\<bbb-Q\>>>> of Puiseux series over an
  algebraically resp. real closed field <with|mode|math|C> is algebraically
  resp. real closed.<htab|5mm><with|mode|math|\<box\>>>

  <\exercise>
    Consider an asymptotic algebraic equation (<reference|N:poleq>) of Newton
    degree <with|mode|math|d>. Let <with|mode|math|\<tau\><rsub|1>,\<ldots\>,<no-break>\<tau\><rsub|k>>
    be the starting terms of (<reference|N:poleq>), with multiplicities
    <with|mode|math|\<mu\><rsub|1>,\<ldots\>,\<mu\><rsub|k>>. Prove that

    <\equation*>
      \<mu\><rsub|1>+\<cdots\>+\<mu\><rsub|k>\<leqslant\>d.
    </equation*>

    Also show that <with|mode|math|\<mu\><rsub|1>+\<cdots\>+\<mu\><rsub|k>=d>
    if <with|mode|math|C> is algebraically closed.
  </exercise>

  <\exercise>
    \;

    <\enumerate-alpha>
      <item>Show that the computation of all solutions to
      (<reference|N:poleq>) can be represented by a finite tree, whose
      non-root nodes are labeled by refinements. Applied to
      (<reference|N:New:ex1>), this would yields the following tree:

      <equation*|<tree|f=<wide|f|~>|<tabular*|<tformat|<table|<row|<cell|f=\<um\>z<rsup|2><space|-0.6spc>+<space|-0.6spc><wide|f|~>>>|<row|<cell|<wide|f|~>\<prec\>z<rsup|2>>>>>>|<tabular*|<tformat|<table|<row|<cell|f=\<um\>z<space|-0.6spc>+<space|-0.6spc><wide|f|~>>>|<row|<cell|<wide|f|~>\<prec\>z>>>>>|<resize|<tree|<tabular*|<tformat|<table|<row|<cell|f=1+<wide|f|~>>>|<row|<cell|<wide|f|~>\<prec\>1>>>>>|<tabular*|<tformat|<table|<row|<cell|f=1-\<mathi\>*z<rsup|1/2><space|-0.6spc>+<space|-0.6spc><wide|<space|-0.6spc>f|~>>>|<row|<cell|<wide|f|~>\<prec\>z<rsup|1/2>>>>>>|<tabular*|<tformat|<table|<row|<cell|f=1+\<mathi\>*z<rsup|1/2><space|-0.6spc>+<space|-0.6spc><wide|f|~>>>|<row|<cell|<wide|f|~>\<prec\>z<rsup|1/2>>>>>>>|1cm||4cm|>|<tabular*|<tformat|<table|<row|<cell|f=\<um\>\<mathi\>**<space|-0.6spc>z<rsup|\<um\>3/2><space|-0.6spc>+<wide|<space|-0.6spc>f|~>>>|<row|<cell|<wide|f|~>\<prec\>z<rsup|\<um\>3/2>>>>>>|<tabular*|<tformat|<table|<row|<cell|f=\<mathi\>*z<rsup|\<um\>3/2><space|-0.6spc>+<space|-0.6spc><wide|f|~>>>|<row|<cell|<wide|f|~>\<prec\>z<rsup|\<um\>3/2>>>>>>>>

      <item>Show that the successors of each node may be ordered in a natural
      way, if <with|mode|math|C> is a real field, and if we restrict our
      attention to real algebraic solutions. Prove that the natural ordering
      on the leaves, which is induced by this ordering, corresponds to the
      usual ordering of the solutions.
    </enumerate-alpha>
  </exercise>

  <\exercise>
    \;

    <\enumerate-alpha>
      <item>Generalize the results of this chapter to asymptotic equations of
      infinite degree in <with|mode|math|f>, but of finite Newton degree.

      <item>Give an example of an asymptotic equation of infinite degree in
      <with|mode|math|f>, with infinitely many solutions.
    </enumerate-alpha>
  </exercise>

  <\exercise>
    Consider an asymptotic polynomial equation
    <with|mode|math|P(f)=0<space|1.2spc>(f\<prec\>\<frak-v\>)> of Newton
    degree<nbsp><with|mode|math|d>, with <with|mode|math|P\<in\>C<gb|\<frak-M\>>[F]>
    and <with|mode|math|\<frak-v\>\<in\>\<frak-M\>>. Consider the monomial
    monoid <with|mode|math|\<frak-U\>=\<frak-M\>\<times\>F<rsup|\<bbb-N\>>>
    with <with|mode|math|\<frak-m\>*F<rsup|i>\<prec\>1\<Leftrightarrow\>\<frak-m\>*\<frak-v\><rsup|i>\<prec\>1\<vee\>(\<frak-m\>*\<frak-v\><rsup|i>=1\<wedge\>i\<gtr\>0)>.

    <\enumerate-alpha>
      <item>Show that there exists a unique invertible series
      <with|mode|math|u\<in\>C<gb|\<frak-U\>>> such that
      <with|mode|math|<wide|P|~>=u*P> is a monoic polynomial in
      <with|mode|math|C<gb|\<frak-M\>>[F]>.

      <item>Show that <with|mode|math|deg <wide|P|~>=d>.
    </enumerate-alpha>
  </exercise>

  <section|Cartesian representations><label|CR-sec>

  In this section, we show that grid-based series may be represented by
  (finite sums of) multivariate Laurent series in which we substitute an
  infinitesimal monomial for each variable. Such representations are very
  useful for finer computations with grid-based series.

  <subsection|Cartesian representations>

  Let <with|mode|math|C<gb|\<frak-M\>>> be a grid-based algebra. A
  <em|Cartesian representation><bi-index|Cartesian|representation> for a
  series <with|mode|math|f\<in\>C<gb|\<frak-M\>>> is a multivariate Laurent
  series <with|mode|math|<wide|f|\<check\>>\<in\>C((<wide|\<frak-z\>|\<check\>><rsub|1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|k>))>,
  such that <with|mode|math|f=<wide|\<varphi\>|^>(<wide|f|\<check\>>)> for
  some morphism of monomial monoids <with|mode|math|\<varphi\>:<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|k><rsup|\<bbb-Z\>>\<rightarrow\>\<frak-M\>>.
  Writing <with|mode|math|<wide|f|\<check\>>=<wide|g|\<check\>>*<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|k><rsup|\<alpha\><rsub|k>>>,
  with <with|mode|math|<wide|g|\<check\>>\<in\>C[[<wide|\<frak-z\>|\<check\>><rsub|1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|k>]]>,
  we may also interpret <with|mode|math|f> as the product of a ``series''
  <with|mode|math|<wide|\<varphi\>|^>(<wide|g|\<check\>>)> in
  <with|mode|math|\<varphi\>(<wide|\<frak-z\>|\<check\>><rsub|1>),\<ldots\>,\<varphi\>(<wide|\<frak-z\>|\<check\>><rsub|k>)>
  and the monomial <with|mode|math|\<frak-m\>=\<varphi\>(<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|k><rsup|\<alpha\><rsub|k>>)>.

  More generally, a <em|semi-Cartesian representation><bi-index*|semi-Cartesian|representation>
  for <with|mode|math|f\<in\>C<gb|\<frak-M\>>> is an expression of the form
  <with|mode|math|f=<wide|\<varphi\>|^>(<wide|g|\<check\>><rsub|1>)*\<frak-m\><rsub|1>+\<cdots\>+<wide|\<varphi\>|^>(<wide|g|\<check\>><rsub|l>)*\<frak-m\><rsub|l>*>,
  where <with|mode|math|g<rsub|1>,\<ldots\>,g<rsub|l>\<in\>C[[<wide|\<frak-z\>|\<check\>><rsub|1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|k>]]>,
  <with|mode|math|\<frak-m\><rsub|1>,\<ldots\>,\<frak-m\><rsub|l>\<in\>\<frak-M\>>
  and <with|mode|math|\<varphi\>:<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<bbb-N\>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|k><rsup|\<bbb-N\>>\<rightarrow\>\<frak-M\>>
  is a morphism of monomial monoids.

  <\proposition>
    <label|CR>

    <\enumerate-alpha>
      <item>Any grid-based series <with|mode|math|f\<in\>C<gb|\<frak-M\>>>
      admits a semi-Cartesian representation.

      <item>If <with|mode|math|\<frak-M\>> is a monomial group, which is
      generated by its infinitesimal elements, then each grid-based series
      <with|mode|math|f\<in\>C<gb|\<frak-M\>>> admits a Cartesian
      representation.
    </enumerate-alpha>
  </proposition>

  <\proof>
    \;

    <\enumerate-alpha>
      <with|font-shape|italic|<item>>Let <with|mode|math|\<frak-m\><rsub|1>,\<ldots\>,\<frak-m\><rsub|k>\<in\>\<frak-M\><rsub|\<prec\>>>
      and <with|mode|math|\<frak-n\><rsub|1>,\<ldots\>,\<frak-n\><rsub|l>\<in\>\<frak-M\>>
      be such that

      <\equation*>
        <with|mode|text|<with|mode|math|supp
        f\<subseteq\>{\<frak-m\><rsub|1>,\<ldots\>,\<frak-m\><rsub|k>}<rsup|\<ast\>>*{\<frak-n\><rsub|1>,\<ldots\>,\<frak-n\><rsub|l>}>.>
      </equation*>

      For each <with|mode|math|\<frak-v\>\<in\>supp f>, let

      <\equation*>
        n<rsub|\<frak-v\>>=card {(\<alpha\><rsub|1>,\<ldots\>,\<alpha\><rsub|k>,i)\<in\>\<bbb-N\><rsup|k>\<times\>{1,\<ldots\>,l}:<with|mode|text|<with|mode|math|\<frak-v\>=\<frak-m\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-m\><rsub|k><rsup|\<alpha\><rsub|k>>*\<frak-n\><rsub|i>>>}.
      </equation*>

      Let

      <equation*|<wide|g|\<check\>><rsub|i>=<big|sum><rsub|\<alpha\><rsub|1>,\<ldots\>,\<alpha\><rsub|k>\<in\>\<bbb-N\><rsup|k>><frac|f<rsub|\<frak-m\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-m\><rsub|k><rsup|\<alpha\><rsub|k>>*\<frak-n\><rsub|i>>|n<rsub|\<frak-m\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-m\><rsub|k><rsup|\<alpha\><rsub|k>>*\<frak-n\><rsub|i>>>*<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|k><rsup|\<alpha\><rsub|k>>>

      for all <with|mode|math|1\<leqslant\>i\<leqslant\>l><with|mode|math|>
      and let <with|mode|math|\<varphi\>:<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<bbb-N\>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|k><rsup|\<bbb-N\>>\<rightarrow\>\<frak-M\>,<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|k><rsup|\<alpha\><rsub|k>>\<mapsto\>\<frak-m\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-m\><rsub|k><rsup|\<alpha\><rsub|k>>>.
      Then

      <\equation*>
        f=<wide|\<varphi\>|^>(<wide|g|\<check\>><rsub|1>)*\<frak-n\><rsub|1>+\<cdots\>+<wide|\<varphi\>|^>(<wide|g|\<check\>><rsub|l>)*\<frak-n\><rsub|l>.
      </equation*>

      <with|font-shape|italic|<item>>For certain
      <with|mode|math|\<frak-m\><rsub|k+1>,\<ldots\>,\<frak-m\><rsub|p>\<in\>\<frak-M\><rsub|\<prec\>>>
      and <with|mode|math|\<beta\><rsub|i,j>\<in\>\<bbb-Z\>>, we may write
      <with|mode|math|\<frak-n\><rsub|i>=\<frak-m\><rsub|k+1><rsup|\<beta\><rsub|i,k+1>>*\<cdots\>*\<frak-m\><rsub|p><rsup|\<beta\><rsub|i,p>>>,
      for all <with|mode|math|1\<leqslant\>i\<leqslant\>l>. Let
      <with|mode|math|\<psi\>:<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|p><rsup|\<bbb-Z\>>\<rightarrow\>\<frak-M\>,<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|p><rsup|\<alpha\><rsub|p>>\<mapsto\>\<frak-m\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-m\><rsub|p><rsup|\<alpha\><rsub|p>>>
      and

      <equation*|<wide|f|\<check\>>=<big|sum><rsub|i=1><rsup|l><wide|g|\<check\>><rsub|i>*<wide|\<frak-z\>|\<check\>><rsub|k+1><rsup|\<beta\><rsub|i,k+1>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|p><rsup|\<beta\><rsub|i,p>>.>

      Then <with|mode|math|f=<wide|\<psi\>|^>(<wide|f|\<check\>>)>.
    </enumerate-alpha>
  </proof>

  Cartesian or semi-Cartesian representations
  <with|mode|math|f<rsub|1>=<wide|\<varphi\>|^><rsub|1>(<wide|f|\<check\>><rsub|1>)>
  and <with|mode|math|f<rsub|2>=<wide|\<varphi\>|^><rsub|2>(<wide|f|\<check\>><rsub|2>)>
  are said to be <em|compatible><subsubindex|Cartesian|representation|compatible><subindex|compatible|Cartesian
  representations>, if <with|mode|math|<wide|f|\<check\>><rsub|1>> and
  <with|mode|math|<wide|f|\<check\>><rsub|2>> belong to the same algebra
  <with|mode|math|C((<wide|\<frak-z\>|\<check\>><rsub|1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|k>))>
  of Laurent series, and if <with|mode|math|\<varphi\><rsub|1>=\<varphi\><rsub|2>>.

  <\proposition>
    <label|CR2>

    <\enumerate-alpha>
      <item>Any <with|mode|math|f<rsub|1>,\<ldots\>,f<rsub|n>\<in\>C<gb|\<frak-M\>>>
      admit compatible semi-Cartesian representations.

      <item>If <with|mode|math|\<frak-M\>> is a monomial group, which is
      generated by its infinitesimal elements, then any
      <with|mode|math|f<rsub|1>,\<ldots\>,f<rsub|n>\<in\>C<gb|\<frak-M\>>>
      admit compatible Cartesian representations.
    </enumerate-alpha>
  </proposition>

  <surround|<with|mode|math|<assign|mx|\<frak-x\>>>||<\proof>
    By the previous proposition, <with|mode|math|f<rsub|1>,\<ldots\>,f<rsub|n>>
    admit semi-Cartesian representations <with|mode|math|f<rsub|i>=<wide|\<varphi\>|^><rsub|i>(<wide|f|\<check\>><rsub|i>)>,
    where <with|mode|math|<wide|f|\<check\>><rsub|i>\<in\>C((<wide|\<frak-z\>|\<check\>><rsub|i,1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|i,k<rsub|i>>))>
    and <with|mode|math|\<varphi\><rsub|i>:<no-break><wide|\<frak-z\>|\<check\>><rsub|i,1><rsup|\<bbb-N\>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|i,k<rsub|i>><rsup|\<bbb-N\>>\<rightarrow\>\<frak-M\>>
    for each <with|mode|math|i>. Now consider

    <eqnarray*|<tformat|<table|<row|<cell|\<psi\>:<big|prod><rsub|i=1><rsup|n><big|prod><rsub|j=1><rsup|k<rsub|i>><wide|\<frak-z\>|\<check\>><rsub|i,j><rsup|\<bbb-N\>><space|1.6spc>>|<cell|\<longrightarrow\>>|<cell|\<frak-M\>>>|<row|<cell|<big|prod><rsub|i=1><rsup|n><big|prod><rsub|j=1><rsup|k<rsub|i>><wide|\<frak-z\>|\<check\>><rsub|i,j><rsup|\<alpha\><rsub|i,j>>>|<cell|\<longmapsto\>>|<cell|<big|prod><rsub|i=1><rsup|n><wide|\<varphi\>|^><rsub|i><left|(><big|prod><rsub|j=1><rsup|k<rsub|i>><wide|\<frak-z\>|\<check\>><rsub|i,j><rsup|\<alpha\><rsub|i,j>><right|)>.>>>>>

    Then <with|mode|math|f<rsub|i>=<wide|\<psi\>|^>(<wide|F|\<check\>><rsub|i>)>
    for each <with|mode|math|i>, where <with|mode|math|<wide|F|\<check\>><rsub|i>>
    is the image of <with|mode|math|<wide|f|\<check\>><rsub|i>> under the
    natural inclusion of <with|mode|math|C((<wide|\<frak-z\>|\<check\>><rsub|i,1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|i,k<rsub|i>>))>
    into <with|mode|math|C((<wide|\<frak-z\>|\<check\>><rsub|1,1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|1,k<rsub|1>>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|n,1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|n,k<rsub|n>>))>.
    This proves (<with|font-shape|italic|a>); part
    (<with|font-shape|italic|b>) is proved in a similar way.
  </proof>>

  <subsection|Inserting new infinitesimal monomials>

  In proposition <reference|CR2> we drastically increased the size of the
  Cartesian basis in order to obtain compatible Cartesian representations.
  The following lemma is often useful, if one wants to keep this size as low
  as possible.

  <lemma|<label|inf-widen>Let <with|mode|math|\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>,\<frak-m\><rsub|1>,\<ldots\>,\<frak-m\><rsub|l>>
  be infinitesimal elements of a totally ordered monomial group
  <with|mode|math|\<frak-M\>> with <with|mode|math|\<bbb-Q\>>-powers, such
  that <with|mode|math|\<frak-m\><rsub|1>,\<ldots\>,\<frak-m\><rsub|l>\<in\>\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>>.
  Then there exist infinitesimal <with|mode|math|\<frak-z\><rprime|'><rsub|1>,\<ldots\>,\<frak-z\><rprime|'><rsub|k>\<in\>\<frak-z\><rsub|1><rsup|\<bbb-Q\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Q\>>>
  with <with|mode|math|\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>,\<frak-m\><rsub|1>,\<ldots\>,\<frak-m\><rsub|l>\<in\>(\<frak-z\><rprime|'><rsub|1>)<rsup|\<bbb-N\>>*\<cdots\>*(\<frak-z\><rprime|'><rsub|k>)<rsup|\<bbb-N\>>>.>

  <\proof>
    It suffices to prove the lemma for <with|mode|math|l=1>; the general case
    follows by induction over <with|mode|math|l>. The case
    <with|mode|math|l=1> is proved by induction over <with|mode|math|k>. For
    <with|mode|math|k=0>, there is nothing to prove. So assume that
    <with|mode|math|k\<geqslant\>1> and let
    <with|mode|math|\<frak-m\><rsub|1>=\<frak-z\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<alpha\><rsub|k>>>
    with <with|mode|math|\<alpha\><rsub|1>,\<ldots\>,\<alpha\><rsub|k>\<in\>\<bbb-Z\>>.
    Without loss of generality, we may assume that
    <with|mode|math|\<alpha\><rsub|k>\<gtr\>0>, modulo a permutation of
    variables. Putting <with|mode|math|\<frak-n\>=\<frak-z\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-z\><rsub|k-1><rsup|\<alpha\><rsub|k-1>>>,
    we now distinguish the following three cases:

    <\enumerate>
      <item>If <with|mode|math|\<frak-n\>\<prec\>1>, then there exist
      infinitesimal <with|mode|math|\<frak-z\><rprime|'><rsub|1>*\<cdots\>*\<frak-z\><rprime|'><rsub|k-1>\<in\>\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k-1><rsup|\<bbb-Z\>>>,
      such that <with|mode|math|\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k-1>,\<frak-n\>\<in\>(\<frak-z\><rprime|'><rsub|1>)<rsup|\<bbb-N\>>*\<cdots\>*(\<frak-z\><rprime|'><rsub|k-1>)<rsup|\<bbb-N\>>>,
      by the induction hypothesis. Taking
      <with|mode|math|\<frak-z\><rprime|'><rsub|k>=\<frak-z\><rsub|k>>, we
      now have <with|mode|math|\<frak-z\><rsub|k>,\<frak-m\><rsub|1>=\<frak-n\>*\<frak-z\><rsub|k><rsup|\<alpha\><rsub|k>>\<in\>(\<frak-z\><rprime|'><rsub|1>)<rsup|\<bbb-N\>>*\<cdots\>*(\<frak-z\><rprime|'><rsub|k>)<rsup|\<bbb-N\>>>,
      since <with|mode|math|\<alpha\><rsub|k>\<gtr\>0>.

      <item>If <with|mode|math|\<frak-n\>=1>, then
      <with|mode|math|\<frak-m\><rsub|1>=\<frak-z\><rsub|k><rsup|\<alpha\><rsub|k>>>,
      and we may take <with|mode|math|\<frak-z\><rprime|'><rsub|1>=\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rprime|'><rsub|k>=\<frak-z\><rsub|k>>.

      <item>If <with|mode|math|\<frak-n\>\<succ\>1>, then there exists
      infinitesimal <with|mode|math|\<frak-z\><rprime|'><rsub|1>*\<cdots\>*\<frak-z\><rprime|'><rsub|k-1>\<in\>\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k-1><rsup|\<bbb-Z\>>>,
      such that <with|mode|math|\<frak-z\><rsub|1><rsup|1/\<alpha\><rsub|k>>,\<ldots\>,\<frak-z\><rsub|k-1><rsup|1/\<alpha\><rsub|k>>,\<frak-n\><rsup|\<um\>1/\<alpha\><rsub|k>>\<in\>(\<frak-z\><rprime|'><rsub|1>)<rsup|\<bbb-N\>>*\<cdots\>*(\<frak-z\><rprime|'><rsub|k-1>)<rsup|\<bbb-N\>>>.
      Taking <with|mode|math|\<frak-z\><rprime|'><rsub|k>=\<frak-z\><rsub|1><rsup|\<alpha\><rsub|1>/\<alpha\><rsub|k>>*\<cdots\>*\<frak-z\><rsub|k-1><rsup|\<alpha\><rsub|k-1>/\<alpha\><rsub|k>>*\<frak-z\><rsub|k>>,
      we again have <with|mode|math|\<frak-z\><rsub|k>=\<frak-z\><rprime|'><rsub|k>*\<frak-n\><rsup|\<um\>1/\<alpha\><rsub|k>>,\<frak-m\><rsub|1>=(\<frak-z\><rprime|'><rsub|k>)<rsup|\<alpha\><rsub|k>>\<in\>(\<frak-z\><rprime|'><rsub|1>)<rsup|\<bbb-N\>>*\<cdots\>*(\<frak-z\><rprime|'><rsub|k>)<rsup|\<bbb-N\>>*>.
    </enumerate>
  </proof>

  <yes-indent>When doing computations on grid-based series in
  <with|mode|math|C<gb|\<frak-M\>>>, one often works with respect to a
  <em|Cartesian basis><bi-index|Cartesian|basis>
  <with|mode|math|\<frak-Z\>=(\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>)>
  of infinitesimal elements in <with|mode|math|\<frak-M\>>. Each time one
  encounters a series <with|mode|math|f\<in\>C<gb|\<frak-M\>>> which cannot
  be represented by a series in <with|mode|math|C((<wide|\<frak-z\>|\<check\>><rsub|1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|k>))>,
  one has to replace <with|mode|math|\<frak-Z\>> by a <em|wider><index|wider
  Cartesian basis> Cartesian basis <with|mode|math|\<frak-Z\><rprime|'>=(\<frak-z\><rprime|'><rsub|1>,\<ldots\>,\<frak-z\><rsub|k<rprime|'>><rprime|'>)>
  with <with|mode|math|\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>\<in\>(\<frak-z\><rprime|'><rsub|1>)<rsup|\<bbb-N\>>*\<cdots\>*(\<frak-z\><rprime|'><rsub|k<rprime|'>>)<rsup|\<bbb-N\>>>.
  The corresponding mapping <with|mode|math|C((<wide|\<frak-z\>|\<check\>><rsub|1>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|k>))\<rightarrow\>C((<wide|\<frak-z\>|\<check\>><rsub|1><rprime|'>,\<ldots\>,<wide|\<frak-z\>|\<check\>><rsub|k<rprime|'>><rprime|'>))>
  is called a <em|widening><index|widening>. Lemma <reference|inf-widen>
  enables us to keep the Cartesian basis reasonably small during the
  computation.

  <section|Local communities><label|LC>

  Let <with|mode|math|C> be a ring and <with|mode|math|\<frak-M\>> a monomial
  group which is generated by its infinitesimal elements. Given a set
  <with|mode|math|A<rsub|k>\<subseteq\>C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>
  for each <with|mode|math|k\<in\>\<bbb-N\>>, we denote by
  <with|mode|math|C<gb|\<frak-M\>><rsub|A>><glossary-explain|<with|mode|math|C<gb|\<frak-M\>><rsub|A>>|subset
  of <with|mode|math|C<gb|\<frak-M\>>> of series with Cartesian
  representation in <with|mode|math|A>> the set of all grid-based series
  <with|mode|math|f\<in\>C<gb|\<frak-M\>>>, which admit a Cartesian
  representation <with|mode|math|<wide|f|\<check\>>\<in\>A<rsub|k>*\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>>
  for some <with|mode|math|k\<in\><no-break>\<bbb-N\>>. In this section, we
  will show that if the <with|mode|math|A<rsub|k>> satisfy appropriate
  conditions, then many types of computations which can be carried out in
  <with|mode|math|C<gb|\<frak-M\>>> can also be carried out in
  <with|mode|math|C<gb|\<frak-M\>><rsub|A>>.

  <subsection|Cartesian communities><label|CC::CC>

  Let <with|mode|math|C> be a ring. A sequence
  <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>> with
  <with|mode|math|A<rsub|k>\<subseteq\>C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>
  is said to be a <em|Cartesian community><subindex|Cartesian|community> over
  <with|mode|math|C>, if the following conditions are satisfied:

  <\description>
    <item*|CC1><with|mode|math|\<frak-z\><rsub|1>\<in\>A<rsub|1>>.

    <item*|CC2><with|mode|math|A<rsub|k>> is a <with|mode|math|C>-algebra for
    each <with|mode|math|k\<in\>\<bbb-N\>>.

    <item*|CC3>The <with|mode|math|A<rsub|k>> are stable under strong
    monomial morphisms.
  </description>

  In <strong|CC3>, a <em|strong monomial morphism><subindex|strong|monomial
  morphism><subindex|monomial|strong <emdash> morphism> is strong
  <with|mode|math|C>-algebra morphism which maps monomials to monomials. In
  our case, a monomial preserving strong morphism from
  <with|mode|math|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]> into
  <with|mode|math|C[[\<frak-z\><rsub|1>,\<ldots\>,<no-break>\<frak-z\><rsub|k<rprime|'>>]]>
  is always of the form

  <eqnarray*|<tformat|<table|<row|<cell|\<sigma\>:C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>|<cell|\<longrightarrow\>>|<cell|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k<rprime|'>>]];>>|<row|<cell|f(\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>)>|<cell|\<longmapsto\>>|<cell|f(\<frak-z\><rsub|1><rsup|\<alpha\><rsub|1,1>>*\<cdots\>*\<frak-z\><rsub|k<rprime|'>><rsup|\<alpha\><rsub|1,k<rprime|'>>>,\<ldots\>,\<frak-z\><rsub|1><rsup|\<alpha\><rsub|k,1>>*\<cdots\>*\<frak-z\><rsub|k<rprime|'>><rsup|\<alpha\><rsub|k,k<rprime|'>>>),>>>>>

  where <with|mode|math|\<alpha\><rsub|i,j>\<in\>\<bbb-N\>> and
  <with|mode|math|<big|sum><rsub|j><big|.>\<alpha\><rsub|i,j>\<neq\>0> for
  all <with|mode|math|i>. In particular, <with|font-series|bold|CA3> implies
  that the <with|mode|math|A<rsub|k>> are stable under widenings.

  <proposition|Let <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>> be a
  Cartesian community over <with|mode|math|C> and let
  <with|mode|math|\<frak-M\>> be a monomial group. Then
  <with|mode|math|C<gb|\<frak-M\>><rsub|A>> is a <with|mode|math|C>-algebra.>

  <proof|We clearly have <with|mode|math|C\<subseteq\>C<gb|\<frak-M\>><rsub|A>>.
  Let <with|mode|math|<wide|f|^>,<wide|g|^>\<in\>C<gb|\<frak-M\>><rsub|A>>.
  Mimicking the proof of proposition <reference|CR2>, we observe that
  <with|mode|math|f> and <with|mode|math|g> admit compatible Cartesian
  representations <with|mode|math|f,g\<in\>A<rsub|k>*\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>>.
  Then <with|mode|math|f+g>, <with|mode|math|f-g> and <with|mode|math|f*g>
  are Cartesian representations of <with|mode|math|<wide|f|^>+<wide|g|^>>,
  <with|mode|math|<wide|f|^>-<wide|g|^>> resp.
  <with|mode|math|<wide|f|^>*<wide|g|^>>.>

  <subsection|Local communities>

  A <em|local community><index|local community> is a Cartesian community
  <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>>, which satisfies the
  following additional conditions:

  <\description>
    <item*|LC1>For each <with|mode|math|f\<in\>A<rsub|k>> with
    <with|mode|math|[\<frak-z\><rsub|k><rsup|0>] f=0>, we have
    <with|mode|math|f/\<frak-z\><rsub|k>\<in\>A<rsub|k>>.

    <item*|LC2><with|mode|math|A<rsub|k>> is stable under
    <with|mode|math|<frac|\<partial\>|\<partial\>\<frak-z\><rsub|k>>> for
    each <with|mode|math|k\<in\>\<bbb-N\>>.

    <item*|LC3>For each <with|mode|math|f\<in\>A<rsub|k+1>> with
    <with|mode|math|[\<frak-z\><rsub|1><rsup|0>*\<cdots\>*\<frak-z\><rsub|k+1><rsup|0>]
    f=0> and <with|mode|math|[\<frak-z\><rsub|1><rsup|0>*\<cdots\>*\<frak-z\><rsub|k><rsup|0>*\<frak-z\><rsub|k+1><rsup|1>]
    f\<in\>C<rsup|\<ast\>>>, we have <with|mode|math|im
    \<varphi\>\<subseteq\>A<rsub|k>>, for the unique strong
    <with|mode|math|C>-algebra morphism <with|mode|math|\<varphi\>:C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k+1>]]\<rightarrow\>C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>,
    such that <with|mode|math|\<varphi\><rsub|\|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>=Id<rsub|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>>
    and <with|mode|math|\<varphi\>(f)=0>.
  </description>

  In <strong|LC1> and <strong|LC3>, the notation
  <with|mode|math|[\<frak-z\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-z\><rsub|p><rsup|\<alpha\><rsub|p>>]
  f> stands for the coefficient of <with|mode|math|\<frak-z\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-z\><rsub|p><rsup|\<alpha\><rsub|p>>><nbsp>in<nbsp><with|mode|math|f>.
  The condition <with|font-series|bold|LC3> should be considered as an
  implicit function theorem for the local community.

  <example|Let <with|mode|math|C> be a subfield of <with|mode|math|\<bbb-C\>>
  and let <with|mode|math|A<rsub|k>=C{<space|-0.4spc>{\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>}<space|-0.4spc>}>
  be the set of convergent power series in <with|mode|math|k> variables over
  <with|mode|math|C>, for each <with|mode|math|k\<in\>\<bbb-N\>>. Then the
  <with|mode|math|A<rsub|k>> form a local community. If
  <with|mode|math|\<frak-M\>> is a monomial group, then
  <with|mode|math|C<cgb|\<frak-M\>>=C<gb|\<frak-M\>><rsub|A>><glossary-explain|<with|mode|math|C<cgb|\<frak-M\>>>|subset
  of convergent grid-based series in <with|mode|math|C<gb|\<frak-M\>>>> will
  also be called the set of <em|convergent grid-based
  series><subindex|convergent|grid-based series><subsubindex|grid-based|series|convergent><subsubindex|series|grid-based|convergent>
  in <with|mode|math|\<frak-M\>> over <with|mode|math|C>.>

  <example|<label|alg-lc>For each <with|mode|math|k\<in\>\<bbb-N\>>, let
  <with|mode|math|A<rsub|k>> be the set of power series in
  <with|mode|math|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>,
  which satisfy an algebraic equation over
  <with|mode|math|C[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]>. Then
  the <with|mode|math|A<rsub|k>> form a local community.>

  <subsection|Faithful Cartesian representations>

  In this and the next section, <with|mode|math|A=(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>>
  is a local community. A Cartesian representation
  <with|mode|math|f\<in\>C((\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>))>
  is said to be <em|faithful><sub-bi-index|Cartesian|representation|faithful><index|faithful
  Cartesian representation>, if for each dominant monomial
  <with|mode|math|\<frak-d\>> of <with|mode|math|f>, there exists a dominant
  monomial <with|mode|math|<wide|\<frak-d\>|^><rprime|'>> of
  <with|mode|math|<wide|f|^>>, with <with|mode|math|<wide|\<frak-d\>|^>\<preccurlyeq\><wide|\<frak-d\>|^><rprime|'>>.

  <\proposition>
    Let <with|mode|math|(A<rsub|i>)<rsub|i\<in\>\<bbb-N\>>> be a local
    community and <with|mode|math|f\<in\>A<rsub|k>>. Then

    <\enumerate-alpha>
      <item>For each <with|mode|math|1\<leqslant\>i\<leqslant\>k> and
      <with|mode|math|\<alpha\>\<in\>\<bbb-Z\>>, we have
      <with|mode|math|[\<frak-z\><rsub|k><rsup|\<alpha\>>]
      f\<in\>A<rsub|k-1>>.

      <item>For each initial segment <with|mode|math|\<frak-I\>\<subseteq\>\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>>,
      we have <with|mode|math|f<rsub|\<frak-I\>>=<big|sum><rsub|\<frak-m\>\<in\>\<frak-I\>>f<rsub|\<frak-m\>>*\<frak-m\>\<in\>A<rsub|k>>.
    </enumerate-alpha>
  </proposition>

  <\proof>
    For each <with|mode|math|\<alpha\>>, let
    <with|mode|math|f<rsub|\<alpha\>>=[\<frak-z\><rsub|k><rsup|\<alpha\>>]
    f>. We will prove (<with|font-shape|italic|a>) by a weak induction over
    <with|mode|math|\<alpha\>>. If <with|mode|math|\<alpha\>=0>, then the
    unique strong <with|mode|math|C>-algebra morphism
    <with|mode|math|\<varphi\>:C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]\<rightarrow\>C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k-1>]]>
    with <with|mode|math|\<varphi\><rsub|\|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k-1>]]>=Id<rsub|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k-1>]]>>
    and <with|mode|math|\<varphi\>(\<frak-z\><rsub|k>)=0> maps each series
    <with|mode|math|f\<in\>C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>
    to its constant coefficient <with|mode|math|f<rsub|0>\<in\>C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k-1>]]>
    in <with|mode|math|\<frak-z\><rsub|k>>. If
    <with|mode|math|\<alpha\>\<gtr\>0>, let

    <equation*|g=<frac|f-f<rsub|0><rsup|>*\<frak-z\><rsub|k><rsup|0>-\<cdots\>-f<rsub|\<alpha\>-1><rsup|>*\<frak-z\><rsub|k><rsup|\<alpha\>-1>|\<frak-z\><rsub|k><rsup|\<alpha\>>>.>

    By the weak induction hypothesis and <with|font-series|bold|LC1>, we have
    <with|mode|math|g\<in\>A<rsub|k>>. Now
    <with|mode|math|f<rsub|\<alpha\>>=[\<frak-z\><rsub|k><rsup|0>] g>.

    In order to prove (<em|b>), let <with|mode|math|\<frak-D\>={\<frak-d\><rsub|1>,\<ldots\>,\<frak-d\><rsub|l>}>
    be the finite anti-chain of maximal elements of
    <with|mode|math|\<frak-I\>>, so that <with|mode|math|\<frak-I\>=in(\<frak-d\><rsub|1>,\<ldots\>,\<frak-d\><rsub|l>)>.
    Let <with|mode|math|n> be the number of variables which effectively occur
    in <with|mode|math|\<frak-D\>>, <abbr|i.e.> the number of
    <with|mode|math|i\<in\>{1,\<ldots\>,k}>, such that
    <with|mode|math|\<frak-d\><rsub|j>=\<frak-z\><rsub|1><rsup|\<alpha\><rsub|1>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<alpha\><rsub|k>>>
    with <with|mode|math|\<alpha\><rsub|i>\<neq\>0> for some
    <with|mode|math|j>. We prove <no-break>(<with|font-shape|italic|b>) by
    weak induction over <with|mode|math|n>. If <with|mode|math|n=0>, then
    either <with|mode|math|l=0> and <with|mode|math|f<rsub|\<frak-I\>>=0>, or
    <with|mode|math|l=1>, <with|mode|math|\<frak-d\><rsub|1>={1}> and
    <with|mode|math|f<rsub|\<frak-I\>>=f>.

    Assume now that <with|mode|math|n\<gtr\>0> and order the variables
    <with|mode|math|\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>> in such
    a way that <with|mode|math|\<frak-z\><rsub|k>> effectively occurs in one
    of the <with|mode|math|\<frak-d\><rsub|i>>. For each
    <with|mode|math|\<alpha\>\<in\>\<bbb-N\>>, let

    <eqnarray*|<tformat|<table|<row|<cell|\<frak-I\><rsub|\<alpha\>>>|<cell|=>|<cell|{\<frak-m\>\<in\>\<frak-z\><rsub|1><rsup|\<bbb-N\>>*\<cdots\>*\<frak-z\><rsub|k-1><rsup|\<bbb-N\>>:\<frak-m\>*\<frak-z\><rsub|k><rsup|\<alpha\>>\<in\>\<frak-I\>};>>|<row|<cell|\<frak-D\><rsub|\<alpha\>>>|<cell|=>|<cell|{\<frak-m\>\<in\>\<frak-z\><rsub|1><rsup|\<bbb-N\>>*\<cdots\>*\<frak-z\><rsub|k-1><rsup|\<bbb-N\>>:\<frak-m\>*\<frak-z\><rsub|k><rsup|\<alpha\>>\<in\>\<frak-D\>}.>>>>>

    We observe that

    <equation*|\<frak-I\><rsub|\<alpha\>>=in(\<frak-D\><rsub|0>\<amalg\>\<cdots\>\<amalg\>\<frak-D\><rsub|\<alpha\>>)\<cap\>\<frak-z\><rsub|1><rsup|\<bbb-N\>>*\<cdots\>*\<frak-z\><rsub|k-1><rsup|\<bbb-N\>>.>

    In particular, if <with|mode|math|\<nu\>> is maximal with
    <with|mode|math|\<frak-D\><rsub|\<nu\>>\<neq\>\<varnothing\>>, then
    <with|mode|math|\<frak-I\><rsub|\<alpha\>>=\<frak-I\><rsub|\<nu\>>> for
    all <with|mode|math|\<alpha\>\<geqslant\>\<nu\>> and

    <equation*|\<frak-I\>=\<frak-I\><rsub|0><space|0.6spc>\<amalg\><space|0.6spc>\<cdots\><space|0.6spc>\<amalg\><space|0.6spc>\<frak-I\><rsub|\<nu\>-1>*\<frak-z\><rsub|k><rsup|\<nu\>-1><space|0.6spc>\<amalg\><space|0.6spc>\<frak-I\><rsub|\<nu\>>*\<frak-z\><rsub|k><rsup|\<nu\>+\<bbb-N\>>,>

    so that

    <equation*|f<rsub|\<frak-I\>>=f<rsub|0,\<frak-I\><rsub|0>>*\<frak-z\><rsub|k><rsup|0>+\<cdots\>+f<rsub|\<nu\>-1,\<frak-I\><rsub|\<nu\>-1>>*\<frak-z\><rsub|k><rsup|\<nu\>-1>+<left|(><frac|f-f<rsub|0><rsup|>*\<frak-z\><rsub|k><rsup|0>-\<cdots\>-f<rsub|k-1><rsup|>*\<frak-z\><rsub|k><rsup|\<nu\>-1>|\<frak-z\><rsub|k><rsup|\<nu\>>><right|)><rsub|\<frak-I\><rsub|\<nu\>>*\<frak-z\><rsub|k><rsup|\<bbb-N\>>>*\<frak-z\><rsub|k><rsup|\<nu\>>.>

    Moreover, for each <with|mode|math|\<alpha\>>, at most
    <with|mode|math|n-1> variables effectively occur in the set
    <with|mode|math|\<frak-D\><rsub|0>\<amalg\>\<cdots\>\<amalg\>\<frak-D\><rsub|\<alpha\>>>
    of dominant monomials of <with|mode|math|\<frak-I\><rsub|\<alpha\>>>.
    Therefore <with|mode|math|f<rsub|\<frak-I\>>\<in\>A<rsub|k>>, by the
    induction hypothesis.
  </proof>

  <\proposition>
    Given a Cartesian representation <with|mode|math|f\<in\>A<rsub|k>*\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>>
    of a series <with|mode|math|<wide|f|^>\<in\>C<gb|\<frak-M\>>>, its
    truncation

    <equation*|<wide|f|~>=f<rsub|{\<frak-m\>\<in\>\<frak-z\><rsub|1><rsup|\<bbb-N\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-N\>>:\<exists\><wide|\<frak-n\>|^>\<in\>supp
    <wide|f|^>,<space|1spc><wide|\<frak-m\>|^>\<preccurlyeq\><wide|\<frak-n\>|^>}>\<in\>A<rsub|k>*\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>>

    is a faithful Cartesian representation of the same series
    <with|mode|math|<wide|f|^>>.<htab|5mm><with|mode|math|\<box\>>
  </proposition>

  <subsection|Applications of faithful Cartesian representations>

  <\proposition>
    <label|ibr-prop>Let <with|mode|math|<wide|f|^>\<in\>C<gb|\<frak-M\>><rsub|A>>
    be series, which is either

    <\enumerate-alpha>
      <item>infinitesimal,

      <item>bounded, or

      <item>regular.
    </enumerate-alpha>

    Then <with|mode|math|<wide|f|^>> admits a Cartesian representation in
    <with|mode|math|A<rsub|k>*\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>><with|mode|text|
    for some <with|mode|math|k\<in\>\<bbb-N\>>, which is also infinitesimal,
    bounded resp. regular.>>
  </proposition>

  <\proof>
    Assume that <with|mode|math|<wide|f|^>> is infinitesimal and let
    <with|mode|math|f\<in\>A<rsub|k>*\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>>
    be a faithful Cartesian representation of <with|mode|math|<wide|f|^>>,
    with dominant monomials <with|mode|math|\<frak-d\><rsub|1>,\<ldots\>,\<frak-d\><rsub|l>\<prec\>1>.
    For each <with|mode|math|i\<in\>{1,\<ldots\>,l}>, let

    <equation*|f<rsub|i>=f<rsub|in(\<frak-d\><rsub|1>,\<ldots\>,\<frak-d\><rsub|i>)>-f<rsub|in(\<frak-d\><rsub|1>,\<ldots\>,\<frak-d\><rsub|i-1>)>\<in\>A<rsub|k>*\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>,>

    with <with|mode|math|\<frak-d\><rsub|f<rsub|i>>=\<frak-d\><rsub|i>>. Then
    <with|mode|math|f=f<rsub|1>+\<cdots\>+f<rsub|l>> and

    <equation*|<wide|f|~>=<big|sum><rsub|i=1><rsup|l>f<rsub|i>**<frac|\<frak-d\><rsub|1>|\<frak-d\><rsub|i>>*\<frak-z\><rsub|k+i>>

    is an infinitesimal Cartesian representation of
    <with|mode|math|<wide|f|^>> in <with|mode|math|A<rsub|k+l>>, when setting
    <with|mode|math|<wide|\<frak-z\>|^><rsub|k+i>=<wide|\<frak-d\>|^><rsub|i>/<wide|\<frak-d\>|^><rsub|1>>
    for each <with|mode|math|i\<in\>{1,\<ldots\>,l}>. This proves
    (<with|font-shape|italic|a>).

    If <with|mode|math|<wide|f|^>> is bounded, then let
    <with|mode|math|g\<in\>A<rsub|k>> be an infinitesimal Cartesian
    representation of <with|mode|math|<wide|g|^>=<wide|f|^>-<wide|f|^><rsub|{1}>>.
    Now <with|mode|math|f=g+<wide|f|^><rsub|{1}>*\<frak-z\><rsub|1><rsup|0>*\<cdots\>*\<frak-z\><rsub|k><rsup|0>\<in\>A<rsub|k>>
    is a bounded Cartesian representation
    of<nbsp><with|mode|math|<wide|f|^>>. This proves
    (<with|font-shape|italic|b>).

    Assume finally that <with|mode|math|<wide|f|^>\<neq\>0> is regular, with
    dominant monomial <with|mode|math|<wide|\<frak-d\>|^>>. Let
    <with|mode|math|g\<in\>A<rsub|k>> be a bounded Cartesian representation
    of <with|mode|math|<wide|g|^>=<wide|f|^>/<wide|\<frak-d\>|^>>. Since
    <with|mode|math|<wide|g|^><rsub|0>\<neq\>0>, the series
    <with|mode|math|g> is necessarily regular. Now take a Cartesian monomial
    <with|mode|math|\<frak-d\>> which represents
    <with|mode|math|<wide|\<frak-d\>|^>> (e.g. among the dominant monomials
    of a faithful Cartesian representation of
    <no-break><with|mode|math|<wide|\<frak-d\>|^>>). Then
    <with|mode|math|f=g*\<frak-d\>> is a regular Cartesian representation of
    <with|mode|math|<wide|f|^>>.
  </proof>

  <subsection|The Newton polygon method revisited>

  <\theorem>
    <label|Cist>Let <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>> be a
    local community over a ring <with|mode|math|C> and let
    <with|mode|math|\<frak-M\>> be a monomial monoid. Consider the polynomial
    equation

    <equation|<wide|P|^><rsub|n>*<wide|f|^><rsup|n>+\<cdots\>+<wide|P|^><rsub|0>=0<label|implpoleq>>

    with coefficients <with|mode|math|<wide|P|^><rsub|0>,\<ldots\>,<wide|P|^><rsub|n>\<in\>C<gb|\<frak-M\><rsub|\<preccurlyeq\>>><rsub|A>>,
    such that <with|mode|math|(<wide|P|^><rsub|0>)<rsub|1>=0> and
    <with|mode|math|(<wide|P|^><rsub|1>)<rsub|1>\<in\>C<rsup|\<ast\>>>. Then
    <no-break><with|font-shape|right|(<reference|implpoleq>)> admits a unique
    solution in <with|mode|math|C<gb|\<frak-M\><rsub|\<prec\>>><rsub|A>>.
  </theorem>

  <\proof>
    By proposition <reference|ibr-prop>, there exist bounded Cartesian
    representations <with|mode|math|P<rsub|0>,\<ldots\>,P<rsub|n>\<in\>A<rsub|k>>
    for certain <with|mode|math|<wide|\<frak-z\>|^><rsub|1>,\<ldots\>,<wide|\<frak-z\>|^><rsub|k>\<in\>\<frak-M\>>.
    Now consider the series

    <equation*|P=P<rsub|0>+P<rsub|1>*\<frak-z\><rsub|k+1>+\<cdots\>+P<rsub|n>*\<frak-z\><rsub|k+1><rsup|n>\<in\>A<rsub|k+1>.>

    We have <with|mode|math|[\<frak-z\><rsub|1><rsup|0>*\<cdots\>*\<frak-z\><rsub|k+1><rsup|0>]
    P=0> and <with|mode|math|[\<frak-z\><rsub|1><rsup|0>*\<cdots\>*\<frak-z\><rsub|k><rsup|0>*\<frak-z\><rsub|k+1><rsup|1>]
    P\<in\>C<rsup|\<ast\>>>, so there exists a strong
    <with|mode|math|C>-algebra morphism <with|mode|math|\<varphi\>:C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k+1>]]\<rightarrow\>C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>,
    such that <with|mode|math|\<varphi\><rsub|\|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>=Id<rsub|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>>
    and <with|mode|math|\<varphi\>(f)=0>. Moreover,
    <with|mode|math|f\<assign\>\<varphi\>(\<frak-z\><rsub|k+1>)\<in\>A<rsub|k>>
    by <with|font-series|bold|LC3>. Since <with|mode|math|\<varphi\>> is an
    morphism of <with|mode|math|C>-algebras, it follows that
    <with|mode|math|P<rsub|0>+P<rsub|1>*f+\<cdots\>+P<rsub|n>*f<rsup|n>=\<varphi\>(P)=0>.
    We conclude that <with|mode|math|<wide|f|^>\<in\>C<gb|\<frak-M\>><rsub|A>>
    satisfies <with|mode|math|<wide|P|^><rsub|n>*<wide|f|^><rsup|n>+\<cdots\>+<wide|P|^><rsub|0>=0>.
    The uniqueness of <with|mode|math|<wide|f|^>> follows from theorem
    <no-break><reference|isth>.
  </proof>

  <theorem|<label|NthLC>Let <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>>
  be a local community over a (real) algebraically closed field
  <with|mode|math|C> and <with|mode|math|\<frak-M\>> a totally ordered
  monomial group with <with|mode|math|\<bbb-Q\>>-powers. Then
  <with|mode|math|C<gb|\<frak-M\>><rsub|A>> is a (real) algebraically closed
  field.>

  <proof|The proof is analogous to the proof of theorem <reference|alg-cl>.
  In the present case, theorem <reference|Cist> ensures that
  <with|mode|math|\<varphi\>\<in\>C<gb|\<frak-M\>><rsub|A>> in step 2 of
  <with|font-family|tt|polynomial_solve>.>

  <exercise|Let <with|mode|math|C> be a ring, <with|mode|math|\<frak-M\>> a
  monomial monoid and <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>> a
  local community. We define <with|mode|math|C<gb|\<frak-M\>><rsub|A>> to be
  the set of series <with|mode|math|f> in <with|mode|math|C<gb|\<frak-M\>>>,
  which admit a semi-Cartesian representation
  <with|mode|math|f=<wide|\<varphi\>|^>(<wide|f|\<check\>><rsub|1>)*\<frak-m\><rsub|1>+\<cdots\>+<wide|\<varphi\>|^>(<wide|f|\<check\>><rsub|p>)*\<frak-m\><rsub|p>>
  with <with|mode|math|<wide|f|\<check\>><rsub|1>,\<ldots\>,<wide|f|\<check\>><rsub|p>\<in\>A<rsub|k>>
  for some <with|mode|math|k\<in\>\<bbb-N\>>,
  <with|mode|math|\<varphi\>:<wide|\<frak-z\>|\<check\>><rsub|1><rsup|\<bbb-N\>>*\<cdots\>*<wide|\<frak-z\>|\<check\>><rsub|k><rsup|\<bbb-N\>>\<rightarrow\>\<frak-M\>>
  and <with|mode|math|><with|mode|math|\<frak-m\><rsub|1>,\<ldots\>,<no-break>\<frak-m\><rsub|p>\<in\>\<frak-M\>>.
  Which results from this section generalize to this more general setting?>

  <exercise|Let <with|mode|math|C> be a field. A series <with|mode|math|f> in
  <with|mode|math|C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]> is
  said to be <em|differentially algebraic><subindex|series|differentially
  algebraic>, if the field generated by its partial derivatives
  <with|mode|math|\<partial\><rsup|i<rsub|1>+\<cdots\>+i<rsub|k>>
  f/(\<partial\> \<frak-z\><rsub|1>)<rsup|i<rsub|1>>*\<cdots\>*(\<partial\>
  \<frak-z\><rsub|k>)<rsup|i<rsub|k>>> has finite transcendence degree over
  <with|mode|math|C>. Prove that the collection of such series forms a local
  community over <with|mode|math|C>.>

  <\exercise>
    Assume that <with|mode|math|C> is an effective field, <abbr|i.e.> all
    field operations can be performed by algorithm. In the sequel, we will
    measure the complexity of algorithms in terms of the number of such field
    operations.

    <\enumerate-alpha>
      <item>A series <with|mode|math|f\<in\>C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>
      is said to be <em|effective><subindex|series|effective>, if there is an
      algorithm which takes <with|mode|math|\<alpha\><rsub|1>,\<ldots\>,\<alpha\><rsub|k>\<in\>\<bbb-N\>>
      on input, and which outputs <with|mode|math|f<rsub|\<alpha\><rsub|1>,\<ldots\>,\<alpha\><rsub|k>>>.
      Show that the collection of effective series form a local community.

      <item>An effective series <with|mode|math|f\<in\>C[[\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>]]>
      is said to be of <em|polynomial time complexity>, if there is an
      algorithm, which takes <with|mode|math|n\<in\>\<bbb-N\>> on input and
      which computes <with|mode|math|f<rsub|\<alpha\><rsub|1>,\<ldots\>,\<alpha\><rsub|n>>>
      for all <with|mode|math|\<alpha\><rsub|1>,\<ldots\>,<no-break>\<alpha\><rsub|n>>
      with <with|mode|math|\<alpha\><rsub|1>+\<cdots\>+\<alpha\><rsub|n>\<leqslant\>k>
      in time <with|mode|math|<binom|n+k|n><rsup|O(1)>>. Show that the
      collection of such series forms a local community. What about even
      better time complexities?
    </enumerate-alpha>
  </exercise>

  <exercise|Let <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>> be a
  local community and let <with|mode|math|f\<in\>A<rsub|k>*\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>>
  be a Cartesian representation of an infinitesimal, bounded or regular
  grid-based series <with|mode|math|<wide|f|^>> in
  <with|mode|math|C<gb|\<frak-M\>>>. Show that, modulo widenings, there
  exists an infinitesimal, bounded resp. regular Cartesian representation of
  <with|mode|math|<wide|f|^>>, with respect to a Cartesian basis with at most
  <with|mode|math|k> elements.>

  <\exercise>
    <label|lc-field-ex>Let <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>>
    be a local community over a field <with|mode|math|C>.

    <\enumerate-alpha>
      <item>If <with|mode|math|f\<in\>C<gb|\<frak-M\>><rsub|A,\<prec\>>> and
      <with|mode|math|g\<in\>A<rsub|1>>, then show that
      <with|mode|math|g\<circ\>f\<in\>C<gb|\<frak-M\>><rsub|A>>.

      <item>If <with|mode|math|\<frak-M\>> is totally ordered, then prove
      that <with|mode|math|C<gb|\<frak-M\>><rsub|A>> is a field.
    </enumerate-alpha>
  </exercise>

  <\exercise>
    <label|lc-candec-ex>Let <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>>
    be a local community over a field <with|mode|math|C> and let
    <with|mode|math|\<frak-M\>> be a totally ordered monomial group. Prove
    that <with|mode|math|f<rsub|\<succ\>>,f<rsub|\<asymp\>>,f<rsub|\<prec\>>\<in\>C<gb|\<frak-M\>><rsub|A>>
    for any <with|mode|math|f\<in\>C<gb|\<frak-M\>><rsub|A>>, and

    <equation*|C<gb|\<frak-M\>><rsub|A>=C<gb|\<frak-M\>><rsub|A,\<succ\>>\<oplus\>C\<oplus\>C<gb|\<frak-M\>><rsub|A,\<prec\>>.>
  </exercise>

  <\exercise>
    Let <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>> be a Cartesian
    community. Given monomial groups <with|mode|math|\<frak-M\>> and
    <with|mode|math|\<frak-N\>>, let <with|mode|math|<value|rsA>(C<gb|\<frak-M\>>,C<gb|\<frak-N\>>)>
    be the set of strong <with|mode|math|C>-algebra morphisms from
    <with|mode|math|C<gb|\<frak-M\>>> into <with|mode|math|C<gb|\<frak-N\>>>
    and <with|mode|math|<value|rsA>(C<gb|\<frak-M\>>,C<gb|\<frak-N\>>)<rsub|A>>
    the set of <with|mode|math|\<varphi\>\<in\><value|rsA>(C<gb|\<frak-M\>>,C<gb|\<frak-N\>>)>,
    such that <with|mode|math|\<varphi\>(\<frak-m\>)\<in\>C<gb|\<frak-N\>><rsub|A>>
    for all <with|mode|math|\<frak-m\>\<in\>\<frak-M\>>.

    <\enumerate-alpha>
      <item>Given <with|mode|math|\<varphi\>\<in\><value|rsA>(C<gb|\<frak-M\>>,C<gb|\<frak-N\>>)<rsub|A>>
      and <with|mode|math|\<psi\>\<in\><value|rsA>(C<gb|\<frak-N\>>,C<gb|\<frak-V\>>)<rsub|A>>,
      where <with|mode|math|\<frak-V\>> is a third monomial group, prove that
      <with|mode|math|\<psi\>\<circ\>\<varphi\>\<in\><value|rsA>(C<gb|\<frak-M\>>,C<gb|\<frak-V\>>)<rsub|A>>.

      <item>Given <with|mode|math|\<varphi\>\<in\><value|rsA>(C<gb|\<frak-M\>>,C<gb|\<frak-N\>>)<rsub|A>>
      and <with|mode|math|\<psi\>\<in\><value|rsA>(C<gb|\<frak-N\>>,C<gb|\<frak-M\>>)>
      such that <with|mode|math|\<psi\>\<circ\>\<varphi\>=Id<rsub|C<gb|\<frak-M\>>>>,
      prove that <with|mode|math|\<psi\>\<in\><value|rsA>(C<gb|\<frak-N\>>,C<gb|\<frak-M\>>)<rsub|A>>.
    </enumerate-alpha>
  </exercise>

  <exercise|<label|conv-mon-group>Let <with|mode|math|C> be a subfield of
  <with|mode|math|\<bbb-C\>> and let <with|mode|math|\<frak-M\>> and
  <with|mode|math|\<frak-N\>> be monomial groups with
  <with|mode|math|\<frak-M\>\<subseteq\>\<frak-N\>>. Prove that
  <with|mode|math|C<cgb|\<frak-M\>>=C<gb|\<frak-M\>>\<cap\>C<cgb|\<frak-N\>>>.
  Does this property generalize to other local communities?>

  <exercise|Let <with|mode|math|(A<rsub|k>)<rsub|k\<in\>\<bbb-N\>>> be the
  local community from example <reference|alg-lc> and let
  <with|mode|math|\<frak-M\>> be a totally ordered monomial group. Prove that
  <with|mode|math|C<gb|\<frak-M\>><rsub|A>> is isomorphic to the algebraic
  closure of <with|mode|math|C[\<frak-M\>]>.>

  <exercise|Does theorem <reference|NthLC> still hold if we remove condition
  <with|font-series|bold|LC2> in the definition of local communities?>

  <\exercise>
    Consider the resolution of <with|mode|math|P(f)=0<space|1.2spc>(f\<prec\>\<frak-v\>)>,
    with <with|mode|math|P\<in\>C<gb|\<frak-M\>><rsub|A>> and
    <with|mode|math|\<frak-v\>\<in\>\<frak-M\>>.

    <\enumerate-alpha>
      <item>Given a starting term <with|mode|math|c*\<frak-m\>> of
      multiplicity <with|mode|math|d>, let <with|mode|math|\<frak-n\>> be
      minimal for <with|mode|math|<op|\<preccurlyeq\>>> such that
      <with|mode|math|P<rsub|i>*\<frak-m\><rsup|i>\<preccurlyeq\>\<frak-n\>>
      for all <with|mode|math|i>. Show that there exist Cartesian coordinates
      <with|mode|math|\<frak-z\><rsub|1>,\<ldots\>,\<frak-z\><rsub|k>> with
      <with|mode|math|\<frak-m\>,\<frak-n\>\<in\>\<frak-z\><rsub|1><rsup|\<bbb-Z\>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Z\>>>,
      in which <with|mode|math|P<rsub|i>*\<frak-m\><rsup|i>/\<frak-n\>>
      admits a bounded Cartesian representations <with|mode|math|u<rsub|i>>
      for all <with|mode|math|0\<leqslant\>i\<leqslant\>n=deg P>.

      <item>Consider a bounded Cartesian representation
      <with|mode|math|\<varphi\>\<in\>A<rsub|k>> with
      <with|mode|math|\<varphi\>\<sim\>c> and let
      <with|mode|math|<wide|u|~><rsub|i>=<big|sum><rsub|k=i><rsup|n><binom|k|i>*u<rsub|k>*\<varphi\><rsup|k-i>>.
      Given <with|mode|math|\<frak-w\>\<in\>\<frak-z\><rsub|1><rsup|\<bbb-Q\><rsup|\<geqslant\>>>*\<cdots\>*\<frak-z\><rsub|k><rsup|\<bbb-Q\><rsup|\<geqslant\>>>>,
      let <with|mode|math|><with|mode|math|Q<rsub|\<frak-w\>>=<big|sum><rsub|i=0><rsup|n><wide|u|~><rsub|i,\<frak-w\><rsup|d-i>>*F<rsup|i>>.
      Show that <with|mode|math|Q=<big|sum><rsub|\<frak-w\>>Q<rsub|\<frak-w\>>*\<frak-w\>>
      is a series in <with|mode|math|C[F][[\<frak-z\><rsub|1><rsup|1/d!>,\<ldots\>,\<frak-z\><rsub|k><rsup|1/d!>]]<rsub|A>>.

      <item>For each <with|mode|math|\<mu\>\<in\>{0,\<ldots\>,d}>, let
      <with|mode|math|\<frak-I\><rsub|\<mu\>>> be initial segment generated
      by the <with|mode|math|\<frak-w\>> such that <with|mode|math|val
      Q<rsub|\<frak-w\>>\<less\><no-break>\<mu\>>, and
      <with|mode|math|\<frak-F\><rsub|\<mu\>>> its complement. We say that
      <with|mode|math|\<varphi\><rsub|\<frak-F\><rsub|\<mu\>>>> is the part
      of multiplicity <with|mode|math|<op|\<geqslant\>>\<mu\>> of
      <with|mode|math|\<varphi\>> as a zero of
      <with|mode|math|u<rsub|0>+\<cdots\>+u<rsub|n>*F<rsup|n>>. Show that
      <with|mode|math|\<varphi\><rsub|\<frak-F\><rsub|\<mu\>>>\<in\>A<rsub|k>>
      can be determined effectively for all <with|mode|math|\<mu\>>.

      <item>In <with|font-family|tt|polynomial_solve>, show that refinements
      of the type <with|mode|math|f=<wide|\<varphi\>|^>*\<frak-m\>+<wide|f|~><space|1.2spc>(<wide|f|~>\<prec\>\<frak-m\>)>,
      where <with|mode|math|\<varphi\>\<in\>C<rsub|k>> is the unique solution
      to <with|mode|math|\<partial\><rsup|d-1>(u<rsub|0>+\<cdots\>+u<rsub|n>*F<rsup|n>)/\<partial\>
      F<rsup|d-1>>, may be replaced by refinements
      <with|mode|math|f=<wide|\<varphi\><rsub|\<frak-F\><rsub|d-1>>|^>*\<frak-m\>+<wide|f|~><space|1.2spc>(<wide|f|~>\<prec\>\<frak-m\>)>.
    </enumerate-alpha>
  </exercise>
</body>

<\initial>
  <\collection>
    <associate|font|roman>
    <associate|font-base-size|12>
    <associate|page-show-hf|true>
    <associate|par-hyphen|professional>
    <associate|preamble|false>
    <associate|window height|1212160>
    <associate|window width|997120>
  </collection>
</initial>

<\references>
  <\collection>
    <associate|CC::CC|<tuple|3.5.1|14>>
    <associate|CR|<tuple|3.11|12>>
    <associate|CR-sec|<tuple|3.4|12>>
    <associate|CR2|<tuple|3.12|13>>
    <associate|Cist|<tuple|3.20|17>>
    <associate|LC|<tuple|3.5|14>>
    <associate|N:New:ex1|<tuple|3.1|2>>
    <associate|N:New:ex1b|<tuple|3.2|2>>
    <associate|N:New:ex1c|<tuple|3.3|3>>
    <associate|N:New:ex2|<tuple|3.7|5>>
    <associate|N:Newton:alg|<tuple|3.3|8>>
    <associate|N:domeq|<tuple|3.14|8>>
    <associate|N:newpoleq|<tuple|3.16|9>>
    <associate|N:pdouble|<tuple|3.7|10>>
    <associate|N:poleq|<tuple|3.13|8>>
    <associate|N:polimpl|<tuple|3.5|8>>
    <associate|N:rlem|<tuple|3.6|9>>
    <associate|N:trdata|<tuple|3.17|9>>
    <associate|Nddec|<tuple|3.3.2|9>>
    <associate|Newcoh|<tuple|3.4|8>>
    <associate|Newpolfig|<tuple|3.1|3>>
    <associate|Newpolfig2|<tuple|3.2|4>>
    <associate|Npol-almost-mult|<tuple|3.1.3|5>>
    <associate|Npol-ex-sec|<tuple|3.1|2>>
    <associate|NthLC|<tuple|3.21|17>>
    <associate|alg-cl|<tuple|3.8|10>>
    <associate|alg-lc|<tuple|3.16|15>>
    <associate|auto-1|<tuple|3|1>>
    <associate|auto-10|<tuple|3.2|2>>
    <associate|auto-11|<tuple|3.2|2>>
    <associate|auto-12|<tuple|3.2|2>>
    <associate|auto-13|<tuple|3.2|2>>
    <associate|auto-14|<tuple|3.2|2>>
    <associate|auto-15|<tuple|3.2|2>>
    <associate|auto-16|<tuple|3.2|2>>
    <associate|auto-17|<tuple|3.1|3>>
    <associate|auto-18|<tuple|3.1.2|3>>
    <associate|auto-19|<tuple|3.2|4>>
    <associate|auto-2|<tuple|3.1|2>>
    <associate|auto-20|<tuple|3.1|4>>
    <associate|auto-21|<tuple|3.1|4>>
    <associate|auto-22|<tuple|3.6|4>>
    <associate|auto-23|<tuple|3.6|4>>
    <associate|auto-24|<tuple|3.6|4>>
    <associate|auto-25|<tuple|3.6|4>>
    <associate|auto-26|<tuple|3.6|4>>
    <associate|auto-27|<tuple|3.1.3|5>>
    <associate|auto-28|<tuple|3.1.3|5>>
    <associate|auto-29|<tuple|3.2|6>>
    <associate|auto-3|<tuple|3.1.1|2>>
    <associate|auto-30|<tuple|3.3|8>>
    <associate|auto-31|<tuple|3.3.1|8>>
    <associate|auto-32|<tuple|3.3.1|8>>
    <associate|auto-33|<tuple|3.3.1|8>>
    <associate|auto-34|<tuple|3.13|8>>
    <associate|auto-35|<tuple|3.13|8>>
    <associate|auto-36|<tuple|3.13|8>>
    <associate|auto-37|<tuple|3.14|8>>
    <associate|auto-38|<tuple|3.14|8>>
    <associate|auto-39|<tuple|3.14|8>>
    <associate|auto-4|<tuple|3.1|2>>
    <associate|auto-40|<tuple|3.14|8>>
    <associate|auto-41|<tuple|3.14|8>>
    <associate|auto-42|<tuple|3.14|8>>
    <associate|auto-43|<tuple|3.14|8>>
    <associate|auto-44|<tuple|3.4|8>>
    <associate|auto-45|<tuple|3.4|8>>
    <associate|auto-46|<tuple|3.4|8>>
    <associate|auto-47|<tuple|3.4|8>>
    <associate|auto-48|<tuple|3.3.2|8>>
    <associate|auto-49|<tuple|3.3.2|9>>
    <associate|auto-5|<tuple|3.1|2>>
    <associate|auto-50|<tuple|3.17|9>>
    <associate|auto-51|<tuple|3.17|9>>
    <associate|auto-52|<tuple|3.3.3|9>>
    <associate|auto-53|<tuple|3.8|10>>
    <associate|auto-54|<tuple|3.10|10>>
    <associate|auto-55|<tuple|3.4|11>>
    <associate|auto-56|<tuple|3.4.1|12>>
    <associate|auto-57|<tuple|3.4.1|12>>
    <associate|auto-58|<tuple|3.4.1|12>>
    <associate|auto-59|<tuple|3.4.1|12>>
    <associate|auto-6|<tuple|3.1|2>>
    <associate|auto-60|<tuple|3.4.1|12>>
    <associate|auto-61|<tuple|b|12>>
    <associate|auto-62|<tuple|b|13>>
    <associate|auto-63|<tuple|3.4.2|13>>
    <associate|auto-64|<tuple|3|13>>
    <associate|auto-65|<tuple|3|14>>
    <associate|auto-66|<tuple|3|14>>
    <associate|auto-67|<tuple|3|14>>
    <associate|auto-68|<tuple|3.5|14>>
    <associate|auto-69|<tuple|3.5|14>>
    <associate|auto-7|<tuple|3.1|2>>
    <associate|auto-70|<tuple|3.5.1|14>>
    <associate|auto-71|<tuple|3.5.1|14>>
    <associate|auto-72|<tuple|3.5.1|14>>
    <associate|auto-73|<tuple|3.5.1|14>>
    <associate|auto-74|<tuple|3.5.2|14>>
    <associate|auto-75|<tuple|3.5.2|15>>
    <associate|auto-76|<tuple|3.15|15>>
    <associate|auto-77|<tuple|3.15|15>>
    <associate|auto-78|<tuple|3.15|15>>
    <associate|auto-79|<tuple|3.15|15>>
    <associate|auto-8|<tuple|3.2|2>>
    <associate|auto-80|<tuple|3.5.3|15>>
    <associate|auto-81|<tuple|3.5.3|15>>
    <associate|auto-82|<tuple|3.5.3|15>>
    <associate|auto-83|<tuple|3.5.3|15>>
    <associate|auto-84|<tuple|3.5.4|15>>
    <associate|auto-85|<tuple|3.5.5|16>>
    <associate|auto-86|<tuple|3.10|17>>
    <associate|auto-87|<tuple|a|17>>
    <associate|auto-88|<tuple|a|17>>
    <associate|auto-89|<tuple|a|?>>
    <associate|auto-9|<tuple|3.2|2>>
    <associate|conv-mon-group|<tuple|3.16|18>>
    <associate|derpol|<tuple|3.18|10>>
    <associate|ex-aspol-eq|<tuple|3.4|3>>
    <associate|ex-aspol-eq2|<tuple|3.6|4>>
    <associate|ex-refinement|<tuple|3.5|4>>
    <associate|expoleq|<tuple|3.7|3>>
    <associate|gly-1|<tuple|3.1|?>>
    <associate|ibr-prop|<tuple|3.19|16>>
    <associate|impl-ser-sec|<tuple|3.2|6>>
    <associate|implpoleq|<tuple|3.19|17>>
    <associate|inf-widen|<tuple|3.13|13>>
    <associate|isth|<tuple|3.3|6>>
    <associate|itbound|<tuple|3.10|7>>
    <associate|itpoleq|<tuple|3.9|7>>
    <associate|lc-candec-ex|<tuple|3.14|?>>
    <associate|lc-field-ex|<tuple|3.13|?>>
    <associate|nc-impl-eq|<tuple|3.12|8>>
    <associate|npol-chap|<tuple|3|1>>
    <associate|real-closed-th|<tuple|3.9|11>>
    <associate|ref|<tuple|3.15|9>>
    <associate|toc-1|<tuple|3|?>>
    <associate|toc-10|<tuple|3.3.3|?>>
    <associate|toc-11|<tuple|3.4|?>>
    <associate|toc-12|<tuple|3.4.1|?>>
    <associate|toc-13|<tuple|3.4.2|?>>
    <associate|toc-14|<tuple|3.4.3|?>>
    <associate|toc-15|<tuple|3.5|?>>
    <associate|toc-16|<tuple|3.5.1|?>>
    <associate|toc-17|<tuple|3.5.2|?>>
    <associate|toc-18|<tuple|3.5.3|?>>
    <associate|toc-19|<tuple|3.5.4|?>>
    <associate|toc-2|<tuple|3.1|?>>
    <associate|toc-20|<tuple|3.5.5|?>>
    <associate|toc-3|<tuple|3.1.1|?>>
    <associate|toc-4|<tuple|3.1.2|?>>
    <associate|toc-5|<tuple|3.1.3|?>>
    <associate|toc-6|<tuple|3.2|?>>
    <associate|toc-7|<tuple|3.3|?>>
    <associate|toc-8|<tuple|3.3.1|?>>
    <associate|toc-9|<tuple|3.3.2|?>>
  </collection>
</references>

<\auxiliary>
  <\collection>
    <\associate|bib>
      vdH:phd

      Sm1875

      Chis86

      Gri91
    </associate>
    <\associate|figure>
      <\tuple|normal>
        <label|Newpolfig>The left-hand side shows the Newton polygon
        associated to the equation (<reference|N:New:ex1>). The slopes of the
        four edges correspond to the starting exponents
        <with|mode|<quote|math>|2>, <with|mode|<quote|math>|1>,
        <with|mode|<quote|math>|0> and <with|mode|<quote|math>|\<um\><frac|3|2>>
        (from left to right). After the substitution
        <with|mode|<quote|math>|f\<rightarrow\>1+<wide|f|~><space|1.2spc>(<wide|f|~>\<prec\>1)>,
        we obtain the equation (<reference|N:New:ex1c>), whose Newton polygon
        is shown at the right-hand side. Each non-zero coefficient
        <with|mode|<quote|math>|P<rsub|i,z<rsup|\<alpha\>>>> in the equation
        (<reference|N:New:ex1>) for <with|mode|<quote|math>|f> induces a
        ``row'' of (potentially) non-zero coefficients
        <with|mode|<quote|math>|<wide|P|~><rsub|<wide|\<imath\>|~>,z<rsup|<wide|\<alpha\>|~>>>>
        in the equation for <with|mode|<quote|math>|<wide|f|~>>, in the
        direction of the arrows. The horizontal direction of the arrows
        corresponds to the slope of the starting exponent
        <no-break><specific|screen|<resize|<move|<with|color|<quote|#A0A0FF>|->|-0.3em|>|0em||0em||>><with|mode|<quote|math>|0>.
        Moreover, the fact that <with|mode|<quote|math>|1> is a starting term
        corresponds to the fact that the coefficient of the lowest left-most
        induced point vanishes.
      </tuple|<pageref|auto-17>>

      <\tuple|normal>
        <label|Newpolfig2>At the left-hand side, we have illustrated the
        Newton polygon for the asymptotic equation
        <with|mode|<quote|math>|P(f)=0<space|1.2spc>(f\<prec\>z<rsup|1/2>)>.
        The dashed line corresponds to the slope <with|mode|<quote|math>|1/2>
        and the edges of the Newton polygon with slope
        <with|mode|<quote|math>|<with|math-condensed|<quote|true>|\<gtr\>>
        1/2> have been highlighted. Notice that the Newton degree
        <with|mode|<quote|math>|d=2> corresponds to the first coordinate of
        the rightmost point on an edge with slope
        <with|mode|<quote|math>|<with|math-condensed|<quote|true>|\<gtr\>>
        1/2>. At the right-hand side, we have shown the ``pivoting'' effect
        around the origin of the substitution
        <with|mode|<quote|math>|f=z<rsup|1/2>*<wide|f|~>> on the Newton
        polygon.
      </tuple|<pageref|auto-19>>
    </associate>
    <\associate|gly>
      <tuple|<vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|Chapter
      3. The Newton polygon method><vspace|1fn>>

      <tuple|normal|<with|mode|<quote|math>|N<rsub|P, \<frak-m\>>>|Newton
      polynomial associated to <with|mode|<quote|math>|\<frak-m\>>|<pageref|auto-36>>

      <tuple|normal|<with|mode|<quote|math>|C<with|math-font-family|<quote|mt>|[<space|-0.6spc>[>\<frak-M\><with|math-font-family|<quote|mt>|]<space|-0.6spc>]><rsub|A>>|subset
      of <with|mode|<quote|math>|C<with|math-font-family|<quote|mt>|[<space|-0.6spc>[>\<frak-M\><with|math-font-family|<quote|mt>|]<space|-0.6spc>]>>
      of series with Cartesian representation in
      <with|mode|<quote|math>|A>|<pageref|auto-69>>

      <tuple|normal|<with|mode|<quote|math>|C<with|math-font-family|<quote|mt>|{<space|-0.6spc>{>\<frak-M\><with|math-font-family|<quote|mt>|}<space|-0.6spc>}>>|subset
      of convergent grid-based series in <with|mode|<quote|math>|C<with|math-font-family|<quote|mt>|[<space|-0.6spc>[>\<frak-M\><with|math-font-family|<quote|mt>|]<space|-0.6spc>]>>|<pageref|auto-76>>
    </associate>
    <\associate|idx>
      <tuple|<tuple|dominant|exponent>|<pageref|auto-4>>

      <tuple|<tuple|series|dominant exponent>|<pageref|auto-5>>

      <tuple|<tuple|valuation>|<pageref|auto-6>>

      <tuple|<tuple|series|valuation>|<pageref|auto-7>>

      <tuple|<tuple|Newton|polynomial>|<pageref|auto-8>>

      <tuple|<tuple|polynomial|Newton>|<pageref|auto-9>>

      <tuple|<tuple|Newton|equation>|<pageref|auto-10>>

      <tuple|<tuple|equation|Newton>|<pageref|auto-11>>

      <tuple|<tuple|starting|exponent>|<pageref|auto-12>>

      <tuple|<tuple|starting|monomial>|<pageref|auto-13>>

      <tuple|<tuple|Newton|polygon>|<pageref|auto-14>>

      <tuple|<tuple|starting|coefficient>|<pageref|auto-15>>

      <tuple|<tuple|starting|term>|<pageref|auto-16>>

      <tuple|<tuple|multiplicative conjugate>|<pageref|auto-20>>

      <tuple|<tuple|conjugate|multiplicative>|<pageref|auto-21>>

      <tuple|<tuple|refinement>|<pageref|auto-22>>

      <tuple|<tuple|admissible refinement>|<pageref|auto-23>>

      <tuple|<tuple|refinement|admissible>|<pageref|auto-24>>

      <tuple|<tuple|quasi-linear|equation>|<pageref|auto-25>>

      <tuple|<tuple|equation|quasi-linear>|<pageref|auto-26>>

      <tuple|<tuple|root|almost multiple>|<pageref|auto-28>>

      <tuple|<tuple|asymptotic|equation>|<pageref|auto-32>>

      <tuple|<tuple|equation|asymptotic>|<pageref|auto-33>>

      <tuple|<tuple|starting|monomial>|<pageref|auto-34>>

      <tuple|<tuple|monomial|starting>|<pageref|auto-35>>

      <tuple|<tuple|Newton|polynomial>|<pageref|auto-37>>

      <tuple|<tuple|polynomial|Newton>|<pageref|auto-38>>

      <tuple|<tuple|starting|term>|<pageref|auto-39>>

      <tuple|<tuple|term|starting>|<pageref|auto-40>>

      <tuple|<tuple|starting|term|multiplicity>|<pageref|auto-41>>

      <tuple|<tuple|term|starting|multiplicity>|<pageref|auto-42>>

      <tuple|<tuple|multiplicity|starting term>|<pageref|auto-43>>

      <tuple|<tuple|Newton|degree>|<pageref|auto-44>>

      <tuple|<tuple|degree|Newton>|<pageref|auto-45>>

      <tuple|<tuple|quasi-linear|equation>|<pageref|auto-46>>

      <tuple|<tuple|equation|quasi-linear>|<pageref|auto-47>>

      <tuple|<tuple|refinement>|<pageref|auto-49>>

      <tuple|<tuple|admissible refinement>|<pageref|auto-50>>

      <tuple|<tuple|refinement|admissible>|<pageref|auto-51>>

      <tuple|<tuple|<with|font-family|<quote|tt>|language|<quote|verbatim>|polynomial_solve>>|<pageref|auto-53>>

      <tuple|<tuple|theorem|Newton-Puiseux>|<pageref|auto-54>>

      <tuple|<tuple|Cartesian|representation>|<pageref|auto-57>>

      <tuple|<tuple|representation|Cartesian>|<pageref|auto-58>>

      <tuple|<tuple|semi-Cartesian representation>|<pageref|auto-59>>

      <tuple|<tuple|representation|semi-Cartesian>|<pageref|auto-60>>

      <tuple|<tuple|Cartesian|representation|compatible>|<pageref|auto-61>>

      <tuple|<tuple|compatible|Cartesian representations>|<pageref|auto-62>>

      <tuple|<tuple|Cartesian|basis>|<pageref|auto-64>>

      <tuple|<tuple|basis|Cartesian>|<pageref|auto-65>>

      <tuple|<tuple|wider Cartesian basis>|<pageref|auto-66>>

      <tuple|<tuple|widening>|<pageref|auto-67>>

      <tuple|<tuple|Cartesian|community>|<pageref|auto-71>>

      <tuple|<tuple|strong|monomial morphism>|<pageref|auto-72>>

      <tuple|<tuple|monomial|strong <with|font|<quote|roman>|\V>
      morphism>|<pageref|auto-73>>

      <tuple|<tuple|local community>|<pageref|auto-75>>

      <tuple|<tuple|convergent|grid-based series>|<pageref|auto-77>>

      <tuple|<tuple|grid-based|series|convergent>|<pageref|auto-78>>

      <tuple|<tuple|series|grid-based|convergent>|<pageref|auto-79>>

      <tuple|<tuple|Cartesian|representation|faithful>|<pageref|auto-81>>

      <tuple|<tuple|representation|Cartesian|faithful>|<pageref|auto-82>>

      <tuple|<tuple|faithful Cartesian representation>|<pageref|auto-83>>

      <tuple|<tuple|series|differentially algebraic>|<pageref|auto-86>>

      <tuple|<tuple|series|effective>|<pageref|auto-87>>
    </associate>
    <\associate|toc>
      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|font-shape|<quote|small-caps>|3.<space|2spc>The
      Newton polygon method> <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <pageref|auto-1><vspace|0.5fn>

      3.1.<space|2spc>The method illustrated by examples
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-2>

      <with|par-left|<quote|1.5fn>|3.1.1.<space|2spc>The Newton polygon and
      its slopes <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-3>>

      <with|par-left|<quote|1.5fn>|3.1.2.<space|2spc>Equations with
      asymptotic constraints and refinements
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-18>>

      <with|par-left|<quote|1.5fn>|3.1.3.<space|2spc>Almost double roots
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-27>>

      3.2.<space|2spc>The implicit series theorem
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-29>

      3.3.<space|2spc>The Newton polygon method
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-30>

      <with|par-left|<quote|1.5fn>|3.3.1.<space|2spc>Newton polynomials and
      Newton degree <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-31>>

      <with|par-left|<quote|1.5fn>|3.3.2.<space|2spc>Decrease of the Newton
      degree during refinements <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-48>>

      <with|par-left|<quote|1.5fn>|3.3.3.<space|2spc>Resolution of asymptotic
      polynomial equations <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-52>>

      3.4.<space|2spc>Cartesian representations
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-55>

      <with|par-left|<quote|1.5fn>|3.4.1.<space|2spc>Cartesian
      representations <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-56>>

      <with|par-left|<quote|1.5fn>|3.4.2.<space|2spc>Inserting new
      infinitesimal monomials <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-63>>

      3.5.<space|2spc>Local communities <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-68>

      <with|par-left|<quote|1.5fn>|3.5.1.<space|2spc>Cartesian communities
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-70>>

      <with|par-left|<quote|1.5fn>|3.5.2.<space|2spc>Local communities
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-74>>

      <with|par-left|<quote|1.5fn>|3.5.3.<space|2spc>Faithful Cartesian
      representations <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-80>>

      <with|par-left|<quote|1.5fn>|3.5.4.<space|2spc>Applications of faithful
      Cartesian representations <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-84>>

      <with|par-left|<quote|1.5fn>|3.5.5.<space|2spc>The Newton polygon
      method revisited <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-85>>
    </associate>
  </collection>
</auxiliary>